@@ -38,12 +38,12 @@
 /* define if getcwd() is broken (such as in SunOS) */
 #undef BROKEN_GETCWD
 
+#undef HAVE_LS_A
+
 @BOTTOM@
 
 #define RCSID(msg) \
-static char *foo_version(void) { extern char *krb4_version; \
-				 foo_version(); return krb4_version; } \
-static char *const rcsid[] = { (char *)rcsid, "@(#)" msg } \
+static /**/const char *const rcsid[] = { (char *)rcsid, "@(#)" msg }
 
 /*
  * Set ORGANIZATION to be the desired organization string printed
@@ -80,6 +80,75 @@ static char *const rcsid[] = { (char *)rcsid, "@(#)" msg } \
 #define NDBM
 #endif
 
+/* ftp stuff -------------------------------------------------- */
+
+#ifndef WTMP_PATH
+#define WTMP_PATH "/var/adm/wtmp"
+#endif
+#define KERBEROS
+
+/* telnet stuff ----------------------------------------------- */
+
+/* define this if you want authentication */
+#undef AUTHENTICATION
+
+/* define this if you have kerberos 4 */
+#undef KRB4
+
+/* define this if you want encryption */
+#undef ENCRYPTION
+
+/* Set this if you want des encryption */
+#undef DES_ENCRYPTION
+
+/* Set this to the default system lead string for telnetd 
+ * can contain %-escapes: %s=sysname, %m=machine, %r=os-release
+ * %v=os-version, %t=tty, %h=hostname, %d=date and time
+ */
+#undef USE_IM
+
+/* define this if you want diagnostics in telnetd */
+#undef DIAGNOSTICS
+
+/* define this if you want support for broken ENV_{VALUE,VAR} systems  */
+#undef ENV_HACK
+
+/* define this if you want support for line mode in telnetd */
+#undef LINEMODE
+
+/* define this if you want support for 4.3BSD kludged line mode  */
+#undef KLUDGELINEMODE
+
+/*  */
+#undef OLD_ENVIRON
+
+/* Define if login doesn't understand -f */
+#undef NO_LOGIN_F
+
+/* Define if login does understand -r */
+#undef LOGIN_R
+
+/* Define if login doesn't understand -h */
+/* */
+#undef NO_LOGIN_H
+
+/* Define if login doesn't understand -p */
+#undef NO_LOGIN_P
+
+/* Used with login -p */
+#undef LOGIN_ARGS
+
+/* Define if there are working stream ptys */
+#undef STREAMSPTY
+
+/* set this to a sensible login */
+#ifndef LOGIN_PATH
+#define LOGIN_PATH BINDIR "/login"
+#endif
+
+
+/* ------------------------------------------------------------ */
+
 /*
  * Define this if your ndbm-library really is berkeley db and creates
  * files that ends in .db.
@@ -95,12 +164,22 @@ static char *const rcsid[] = { (char *)rcsid, "@(#)" msg } \
 /* Location of the master key file, default value lives in <kdc.h> */
 #undef MKEYFILE
 
+/* Define if you don't want support for afs, might be a good idea on
+   AIX if you don't have afs */
+
+#undef NO_AFS
+
 #ifdef VOID_RETSIGTYPE
 #define SIGRETURN(x) return
 #else
 #define SIGRETURN(x) return (RETSIGTYPE)(x)
 #endif
 
+/* utmpx is defined in some silly standard */
+#if defined(HAVE_UTMPX_H) && !defined(__osf__)
+#define HAVE_UTMPX
+#endif
+
 /*
  * AIX braindamage!
  */
@@ -121,3 +200,17 @@ static char *const rcsid[] = { (char *)rcsid, "@(#)" msg } \
 #define SunOS 4
 #endif
 #endif
+
+#if defined(__sgi) || defined(sgi)
+#if defined(_SYSTYPE_SVR4)
+#define IRIX 5
+#else
+#define IRIX 4
+#endif
+#endif
+
+
+/* IRIX 4 braindamage */
+#if IRIX == 4 && !defined(__STDC__)
+#define __STDC__ 0
+#endif
