@@ -15,7 +15,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_util.c,v 1.22 1996/06/06 01:01:45 joda Exp $");
+RCSID("$Id: kdb_util.c,v 1.23 1996/06/27 03:55:29 assar Exp $");
 
 static char *prog; 
 
@@ -61,7 +61,7 @@ time_explode(char *cp)
     if (strlen(cp) > 10) {		/* new format */
 	(void) strncpy(wbuf, cp, 4);
 	wbuf[4] = 0;
-	tp.tm_year = atoi(wbuf);
+	tp.tm_year = atoi(wbuf) - 1900;
 	cp += 4;			/* step over the year */
 	local = 0;			/* GMT */
     } else {				/* old format: local time, 
@@ -69,7 +69,7 @@ time_explode(char *cp)
 	wbuf[0] = *cp++;
 	wbuf[1] = *cp++;
 	wbuf[2] = 0;
-	tp.tm_year = 1900 + atoi(wbuf);
+	tp.tm_year = atoi(wbuf);
 	local = 1;			/* local */
     }
 
@@ -91,7 +91,7 @@ time_explode(char *cp)
     tp.tm_min = atoi(wbuf);
 
 
-    return(maketime(&tp, local));
+    return(tm2time(tp, local));
 }
 
 static int
