@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kstash.c,v 1.7 1996/03/28 11:10:19 bg Exp $");
+RCSID("$Id: kstash.c,v 1.8 1996/05/29 23:23:15 assar Exp $");
 
 /* change this later, but krblib_dbm needs it for now */
 char   *progname;
@@ -21,8 +21,8 @@ static des_key_schedule master_key_schedule;
 static void 
 clear_secrets(void)
 {
-    bzero(master_key_schedule, sizeof(master_key_schedule));
-    bzero(master_key, sizeof(master_key));
+    memset(master_key_schedule, 0, sizeof(master_key_schedule));
+    memset(master_key, 0, sizeof(master_key));
 }
 
 int
