@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: klogin.c,v 1.9 1996/01/02 15:55:42 bg Exp $");
+RCSID("$Id: klogin.c,v 1.12 1996/03/24 06:56:37 assar Exp $");
 
 #ifdef KERBEROS
 
@@ -89,9 +89,11 @@ klogin(pw, instance, localhost, password)
 	 */
 
 	if (strcmp(instance, "root") != 0)
-		(void)sprintf(tkt_location, "%s%d_%d", TKT_ROOT, pw->pw_uid, getpid());
+		(void)sprintf(tkt_location, "%s%d_%d",
+			      TKT_ROOT, (int)pw->pw_uid, (int)getpid());
 	else {
-		(void)sprintf(tkt_location, "%s_root_%d", TKT_ROOT, pw->pw_uid);
+		(void)sprintf(tkt_location, "%s_root_%d", TKT_ROOT,
+			      (int)pw->pw_uid);
 	}
 	krbtkfile_env = tkt_location;
 	(void)krb_set_tkt_string(tkt_location);
@@ -120,7 +122,7 @@ klogin(pw, instance, localhost, password)
 	if (kerror != INTK_OK) {
 		if (kerror != INTK_BADPW && kerror != KDC_PR_UNKNOWN) {
 			syslog(LOG_ERR, "Kerberos intkt error: %s",
-			    krb_err_txt[kerror]);
+			    krb_get_err_text(kerror));
 			dest_tkt();
 		}
 		return (1);
@@ -130,7 +132,7 @@ klogin(pw, instance, localhost, password)
 		syslog(LOG_ERR, "chown tkfile (%s): %m", TKT_FILE);
 
 	(void)strncpy(savehost, krb_get_phost(localhost), sizeof(savehost));
-	savehost[sizeof(savehost)-1] = NULL;
+	savehost[sizeof(savehost)-1] = '\0';
 
 #ifdef KLOGIN_PARANOID
 	/*
@@ -142,15 +144,15 @@ klogin(pw, instance, localhost, password)
 	if (kerror == KDC_PR_UNKNOWN) {
 		syslog(LOG_NOTICE,
     		    "warning: TGT not verified (%s); %s.%s not registered, or srvtab is wrong?",
-		    krb_err_txt[kerror], VERIFY_SERVICE, savehost);
+		    krb_get_err_text(kerror), VERIFY_SERVICE, savehost);
 		notickets = 0;
 		return (1);
 	}
 
 	if (kerror != KSUCCESS) {
-		warnx("unable to use TGT: (%s)", krb_err_txt[kerror]);
+		warnx("unable to use TGT: (%s)", krb_get_err_text(kerror));
 		syslog(LOG_NOTICE, "unable to use TGT: (%s)",
-		    krb_err_txt[kerror]);
+		    krb_get_err_text(kerror));
 		dest_tkt();
 		return (1);
 	}
@@ -173,15 +175,15 @@ klogin(pw, instance, localhost, password)
 
 	/* undecipherable: probably didn't have a srvtab on the local host */
 	if (kerror == RD_AP_UNDEC) {
-		syslog(LOG_NOTICE, "krb_rd_req: (%s)\n", krb_err_txt[kerror]);
+		syslog(LOG_NOTICE, "krb_rd_req: (%s)\n", krb_get_err_text(kerror));
 		dest_tkt();
 		return (1);
 	}
 	/* failed for some other reason */
 	warnx("unable to verify %s ticket: (%s)", VERIFY_SERVICE,
-	    krb_err_txt[kerror]);
+	    krb_get_err_text(kerror));
 	syslog(LOG_NOTICE, "couldn't verify %s ticket: %s", VERIFY_SERVICE,
-	    krb_err_txt[kerror]);
+	    krb_get_err_text(kerror));
 	dest_tkt();
 	return (1);
 #else
