@@ -39,7 +39,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login.c,v 1.66 1996/06/15 09:41:40 assar Exp $");
+RCSID("$Id: login.c,v 1.68 1996/08/04 22:40:59 assar Exp $");
 
 #ifdef	xSKEY			/* Don't bother to find this header file. */
 #include <skey.h>
@@ -73,7 +73,7 @@ extern void login __P((struct utmp *));
  * This bounds the time given to login.  Not a define so it can
  * be patched on machines where it's too small.
  */
-u_int	timeout = 300;
+u_int	login_timeout = 300;
 
 #ifdef KERBEROS
 int	notickets = 1;
@@ -142,7 +142,7 @@ main(argc, argv)
 
         /* Read defaults file and set the login timeout period. */
         sysv_defaults();
-        timeout = atoi(default_timeout);
+        login_timeout = atoi(default_timeout);
         maxtrys = atoi(default_maxtrys);
         if (sscanf(default_umask, "%o", &mask) != 1 || (mask & ~0777))
                 syslog(LOG_WARNING, "bad umask default: %s", default_umask);
@@ -150,7 +150,7 @@ main(argc, argv)
                 umask(mask);
 
 	(void)signal(SIGALRM, timedout);
-	(void)alarm(timeout);
+	(void)alarm(login_timeout);
 	(void)signal(SIGQUIT, SIG_IGN);
 	(void)signal(SIGINT, SIG_IGN);
 	(void)setpriority(PRIO_PROCESS, 0, 0);
@@ -402,7 +402,8 @@ main(argc, argv)
 #ifdef KERBEROS
 		if (authok == 0)
 #endif
-		if (pwd && !rval && rootlogin && !rootterm(tty)) {
+		if (pwd && !rval && rootlogin && !rootterm(tty)
+		    && !rootterm(ttyn)) {
 			(void)fprintf(stderr,
 			    "%s login refused on this terminal.\n",
 			    pwd->pw_name);
@@ -749,7 +750,8 @@ timedout(signo)
 	int signo;
 {
 
-	(void)fprintf(stderr, "Login timed out after %d seconds\n", timeout);
+	(void)fprintf(stderr, "Login timed out after %d seconds\n",
+		      login_timeout);
 	exit(0);
 }
 
