@@ -9,7 +9,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login_access.c,v 1.8 1996/03/13 14:26:49 assar Exp $");
+RCSID("$Id: login_access.c,v 1.9 1996/04/23 14:04:46 bg Exp $");
 
 #ifdef LOGIN_ACCESS
 
@@ -125,7 +125,7 @@ int    group;
 char   *machine;
 char   *user;
 {
-#ifdef NIS
+#ifdef HAVE_YP_GET_DEFAULT_DOMAIN
     static char *mydomain = 0;
 
     if (mydomain == 0)
