@@ -35,7 +35,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rcp.c,v 1.23 1996/05/12 18:45:32 joda Exp $");
+RCSID("$Id: rcp.c,v 1.24 1996/07/30 15:46:08 joda Exp $");
 
 /* Globals */
 char *__progname;
@@ -191,7 +191,11 @@ allocbuf(BUF *bp, int fd, int blksize)
 		run_err("fstat: %s", strerror(errno), "");
 		return (0);
 	}
+#ifdef HAVE_ST_BLKSIZE
 	size = ROUNDUP(stb.st_blksize, blksize);
+#else
+	size = blksize;
+#endif
 	if (size == 0)
 		size = blksize;
 	if (bp->cnt >= size)
