@@ -38,7 +38,7 @@
  */
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogin.c,v 1.32 1996/05/29 23:23:22 assar Exp $");
+RCSID("$Id: rlogin.c,v 1.35 1996/06/28 17:55:05 bg Exp $");
 
 #include <termios.h>
 
@@ -129,14 +129,7 @@ get_window_size(fd, wp)
 
 struct	winsize winsize;
 
-/*
- * reader: read from remote: line -> 1
- */
-#define	READING	1
-#define	WRITING	2
-
-jmp_buf rcvtop;
-int parent, rcvcnt, rcvstate;
+int parent, rcvcnt;
 char rcvbuf[8 * 1024];
 
 static void
@@ -249,8 +242,18 @@ msg(char *str)
 	(void)fprintf(stderr, "rlogin: %s\r\n", str);
 }
 
+/*
+ * There is a race in the SunOS5 rlogind. If the slave end has not yet
+ * been opened by the child when setting tty size the size is reset to
+ * zero when the child opens it. Therefore we send the window update
+ * twice.
+ */
+
+static int tty_kludge = 1;
+
+/* Return the number of OOB bytes processed. */
 static
-RETSIGTYPE
+int
 oob_real()
 {
 	struct termios tty;
@@ -260,11 +263,15 @@ oob_real()
 	out = O_RDWR;
 	rcvd = 0;
 	if (recv(rem, &mark, 1, MSG_OOB) < 0) {
-		return;
+		return -1;
 	}
 	if (mark & TIOCPKT_WINDOW) {
 		/* Let server know about window size changes */
 		(void)kill(parent, SIGUSR1);
+	} else if (tty_kludge) {
+		/* Let server know about window size changes */
+		(void)kill(parent, SIGUSR1);
+		tty_kludge = 0;
 	}
 	if (!eight && (mark & TIOCPKT_NOSTOP)) {
 		(void)tcgetattr(0, &tty);
@@ -301,18 +308,10 @@ oob_real()
 		 * anyway.
 		 */
 		rcvcnt = 0;
-		longjmp(rcvtop, 1);
 	}
 
 	/* oob does not do FLUSHREAD (alas!) */
-
-	/*
-	 * If we filled the receive buffer while a read was pending, longjmp
-	 * to the top to restart appropriately.  Don't abort a pending write,
-	 * however, or we won't know how much was written.
-	 */
-	if (rcvd && rcvstate == READING)
-		longjmp(rcvtop, 1);
+	return 1;
 }
 
 /* reader: read from remote: line -> 1 */
@@ -322,12 +321,10 @@ reader(void)
 	int n, remaining;
 	char *bufp;
 
-	(void)setjmp(rcvtop);
 	bufp = rcvbuf;
 	for (;;) {
 	        fd_set readfds, exceptfds;
 		while ((remaining = rcvcnt - (bufp - rcvbuf)) > 0) {
-			rcvstate = WRITING;
 			n = write(STDOUT_FILENO, bufp, remaining);
 			if (n < 0) {
 				if (errno != EINTR)
@@ -338,7 +335,6 @@ reader(void)
 		}
 		bufp = rcvbuf;
 		rcvcnt = 0;
-		rcvstate = READING;
 
 		FD_ZERO (&readfds);
 		FD_SET (rem, &readfds);
@@ -355,15 +351,18 @@ reader(void)
 			    }
 		    }
 
-		if (FD_ISSET(rem, &readfds))
-		    /* do it below */;
-		else if (FD_ISSET(rem, &exceptfds))
-		    {
-			oob_real(0);
-			continue;
-		    }
-		else
-		    fprintf(stderr, "nothing to read?\n");
+		if (!FD_ISSET(rem, &exceptfds) && !FD_ISSET(rem, &readfds))
+		  {
+		    fprintf(stderr, "select: nothing to read?\n");
+		    continue;
+		  }
+
+		if (FD_ISSET(rem, &exceptfds))
+		  if (oob_real() >= 1)
+		    continue;	/* First check if there is more OOB data. */
+
+		if (!FD_ISSET(rem, &readfds))
+		    continue;	/* Nothing to read. */
 
 		if (doencrypt)
 #ifdef NOENCRYPTION
