@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogind.c,v 1.59 1996/06/14 00:56:35 assar Exp $");
+RCSID("$Id: rlogind.c,v 1.64 1996/07/22 11:34:36 joda Exp $");
 
 #include <termios.h>
 
@@ -112,17 +112,15 @@ struct	passwd *pwd;
 
 static const char *new_login = _PATH_LOGIN;
 
-void	doit __P((int, struct sockaddr_in *));
-int	control __P((int, char *, int));
-void	protocol __P((int, int));
-void	cleanup __P((int));
+static void	doit __P((int, struct sockaddr_in *));
+static int	control __P((int, char *, int));
+static void	protocol __P((int, int));
+static void	cleanup __P((int));
 void	fatal __P((int, const char *, int));
-int	do_rlogin __P((struct sockaddr_in *));
-void	setup_term __P((int));
-int	do_krb_login __P((struct sockaddr_in *));
-void	usage __P((void));
-int	local_domain __P((char *));
-char	*topdomain __P((char *));
+static int	do_rlogin __P((struct sockaddr_in *));
+static void	setup_term __P((int));
+static int	do_krb_login __P((struct sockaddr_in *));
+static void	usage __P((void));
 
 static
 int
@@ -412,7 +410,8 @@ int	confirmed;
 struct winsize win = { 0, 0, 0, 0 };
 
 
-void doit(int f, struct sockaddr_in *fromp)
+static void
+doit(int f, struct sockaddr_in *fromp)
 {
 	int master, pid, on = 1;
 	int authenticated = 0;
@@ -547,21 +546,20 @@ void doit(int f, struct sockaddr_in *fromp)
 	cleanup(0);
 }
 
-char	magic[2] = { 0377, 0377 };
-char	oobdata[] = {TIOCPKT_WINDOW};
+const char	magic[2] = { 0377, 0377 };
 
 /*
  * Handle a "control" request (signaled by magic being present)
  * in the data stream.  For now, we are only willing to handle
  * window size changes.
  */
-int control(int master, char *cp, int n)
+static int
+control(int master, char *cp, int n)
 {
 	struct winsize w;
 
 	if (n < 4+sizeof (w) || cp[2] != 's' || cp[3] != 's')
 		return (0);
-	oobdata[0] &= ~TIOCPKT_WINDOW;	/* we know he heard */
 	memcpy(&w, cp+4, sizeof(w));
 	w.ws_row = ntohs(w.ws_row);
 	w.ws_col = ntohs(w.ws_col);
@@ -571,10 +569,44 @@ int control(int master, char *cp, int n)
 	return (4+sizeof (w));
 }
 
+static
+void
+send_oob(int fd, char c)
+{
+  static char last_oob = 0;
+
+#if (SunOS == 5) || defined(__hpux)
+  /*
+   * PSoriasis and HP-UX always send TIOCPKT_DOSTOP at startup so we
+   * can avoid sending OOB data and thus not break on Linux by merging
+   * TIOCPKT_DOSTOP into the first TIOCPKT_WINDOW.
+   */
+  static int oob_kludge = 2;
+  if (oob_kludge == 2)
+    {
+      oob_kludge--;		/* First time send nothing */
+      return;
+    }
+  else if (oob_kludge == 1)
+    {
+      oob_kludge--;		/* Second time merge TIOCPKT_WINDOW */
+      c |= TIOCPKT_WINDOW;
+    }
+#endif
+
+#define	pkcontrol(c) ((c)&(TIOCPKT_FLUSHWRITE|TIOCPKT_NOSTOP|TIOCPKT_DOSTOP))
+  c = pkcontrol(c);
+  /* Multiple OOB data breaks on Linux, avoid it when possible. */
+  if (c != last_oob)
+    send(fd, &c, 1, MSG_OOB);
+  last_oob = c;
+}
+
 /*
  * rlogin "protocol" machine.
  */
-void protocol(int f, int master)
+static void
+protocol(int f, int master)
 {
 	char pibuf[1024+1], fibuf[1024], *pbp, *fbp;
 	register pcc = 0, fcc = 0;
@@ -587,7 +619,9 @@ void protocol(int f, int master)
 	 * (our controlling tty is the master pty).
 	 */
 	(void) signal(SIGTTOU, SIG_IGN);
-	send(f, oobdata, 1, MSG_OOB);	/* indicate new rlogin */
+
+	send_oob(f, TIOCPKT_WINDOW); /* indicate new rlogin */
+
 	if (f > master)
 		nfd = f + 1;
 	else
@@ -625,12 +659,10 @@ void protocol(int f, int master)
 			sleep(5);
 			continue;
 		}
-#define	pkcontrol(c)	((c)&(TIOCPKT_FLUSHWRITE|TIOCPKT_NOSTOP|TIOCPKT_DOSTOP))
 		if (FD_ISSET(master, &ebits)) {
 			cc = readstream(master, &cntl, 1);
 			if (cc == 1 && pkcontrol(cntl)) {
-				cntl |= oobdata[0];
-				send(f, &cntl, 1, MSG_OOB);
+				send_oob(f, cntl);
 				if (cntl & TIOCPKT_FLUSHWRITE) {
 					pcc = 0;
 					FD_CLR(master, &ibits);
@@ -695,8 +727,7 @@ void protocol(int f, int master)
 					FD_SET(f, &obits);	/* try write */
 			} else {
 				if (pkcontrol(pibuf[0])) {
-					pibuf[0] |= oobdata[0];
-					send(f, &pibuf[0], 1, MSG_OOB);
+					send_oob(f, pibuf[0]);
 				}
 				pcc = 0;
 			}
@@ -728,7 +759,8 @@ void protocol(int f, int master)
 	}
 }
 
-void cleanup(int signo)
+static void
+cleanup(int signo)
 {
 	char *p;
 
@@ -748,7 +780,8 @@ void cleanup(int signo)
 	exit(1);
 }
 
-void fatal(int f, const char *msg, int syserr)
+void
+fatal(int f, const char *msg, int syserr)
 {
 	int len;
 	char buf[BUFSIZ], *bp = buf;
@@ -809,9 +842,8 @@ do_rlogin(struct sockaddr_in *dest)
 	return (iruserok(dest->sin_addr.s_addr, 0, rusername, lusername));
 }
 
-extern	char **environ;
-
-void setup_term(int fd)
+static void 
+setup_term(int fd)
 {
 	register char *cp = strchr(term+ENVSIZE, '/');
 	char *speed;
@@ -858,7 +890,8 @@ void setup_term(int fd)
  * Return -1 on valid authentication, no authorization
  * Return >0 for error conditions
  */
-int do_krb_login(struct sockaddr_in *dest)
+static int
+do_krb_login(struct sockaddr_in *dest)
 {
 	int rc;
 	char instance[INST_SZ], version[VERSION_SIZE];
@@ -913,45 +946,9 @@ int do_krb_login(struct sockaddr_in *dest)
 
 }
 
-void usage(void)
+static void
+usage(void)
 {
-	syslog(LOG_ERR, "usage: rlogind [-aln] [-k | -v]");
-}
-
-/*
- * Check whether host h is in our local domain,
- * defined as sharing the last two components of the domain part,
- * or the entire domain part if the local domain has only one component.
- * If either name is unqualified (contains no '.'),
- * assume that the host is local, as it will be
- * interpreted as such.
- */
-int local_domain(char *h)
-{
-	char localhost[MaxHostNameLen];
-	char *p1, *p2;
-
-	localhost[0] = 0;
-	(void) k_gethostname(localhost, sizeof(localhost));
-	p1 = topdomain(localhost);
-	p2 = topdomain(h);
-	if (p1 == NULL || p2 == NULL || !strcasecmp(p1, p2))
-		return (1);
-	return (0);
-}
-
-char *topdomain(char *h)
-{
-	register char *p;
-	char *maybe = NULL;
-	int dots = 0;
-
-	for (p = h + strlen(h); p >= h; p--) {
-		if (*p == '.') {
-			if (++dots == 2)
-				return (p);
-			maybe = p;
-		}
-	}
-	return (maybe);
+	syslog(LOG_ERR,
+	       "usage: rlogind [-ailn] [-p port] [-x] [-L login] [-k | -v]");
 }
