@@ -42,7 +42,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rshd.c,v 1.29 1996/05/29 23:23:26 assar Exp $");
+RCSID("$Id: rshd.c,v 1.30 1996/07/30 15:46:25 joda Exp $");
 
 #include <sys/ioctl.h>
 
@@ -55,11 +55,11 @@ static int	log_success;	/* If TRUE, log all successful accesses */
 static int	new_pag = 1;	/* Put process in new PAG by default */
 static int	sent_null;
 
-void	 doit __P((struct sockaddr_in *));
-void	 error __P((const char *, ...));
-int	 local_domain __P((char *));
-char	*topdomain __P((char *));
-void	 usage __P((void));
+void	 doit (struct sockaddr_in *);
+void	 error (const char *, ...);
+int	 local_domain (char *);
+char	*topdomain (char *);
+void	 usage (void);
 
 #define	VERSION_SIZE	9
 #define SECURE_MESSAGE  "This rsh session is using DES encryption for all transmissions.\r\n"
