@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: su.c,v 1.45 1996/05/31 08:34:24 bg Exp $");
+RCSID("$Id: su.c,v 1.48 1996/07/22 11:34:37 joda Exp $");
 
 #ifdef SYSV_SHADOW
 #include "sysv_shadow.h"
@@ -57,7 +57,6 @@ main(argc, argv)
 	int argc;
 	char **argv;
 {
-	extern char **environ;
 	extern int errno, optind;
 	register struct passwd *pwd;
 	register char *p, **g;
@@ -183,17 +182,20 @@ main(argc, argv)
 		break;
 	    }
 	  /* if target requires a password, verify it */
-	  if (*pwd->pw_passwd) {
+	  if (ruid && *pwd->pw_passwd) {
 	    char prompt[128];
+	    char passwd[256];
 	    sprintf(prompt, "%s's Password: ", pwd->pw_name);
-	    p = getpass(prompt);
-	    if (strcmp(pwd->pw_passwd, crypt(p, pwd->pw_passwd))) {
+	    des_read_pw_string (passwd, sizeof(passwd), prompt, 0);
+	    if (strcmp(pwd->pw_passwd, crypt(passwd, pwd->pw_passwd))) {
+	      memset (passwd, 0, sizeof(passwd));
 	      fprintf(stderr, "Sorry\n");
 	      syslog(LOG_AUTH|LOG_WARNING,
 		     "BAD SU %s to %s%s", username,
 		     user, ontty());
 	      exit(1);
 	    }
+	    memset (passwd, 0, sizeof(passwd));
 	  }
 	}
 	if (asme) {
@@ -362,13 +364,14 @@ kerberos(char *username, char *user, int uid)
 	 */
 	{
 	  char prompt[128];
-	  char *passw;
+	  char passw[256];
+
 	  sprintf(prompt, "%s%s%s@%s's Password: ",
 		  (uid == 0 ? username : user),
 		  (uid == 0 ? "." : ""),
 		  (uid == 0 ? root_inst : ""),
 		  lrealm);
-	  passw = getpass(prompt);
+	  des_read_pw_string(passw, sizeof(passw), prompt, 0);
 	  kerno = krb_get_pw_in_tkt((uid == 0 ? username : user),
 				    (uid == 0 ? root_inst : ""), lrealm,
 				    "krbtgt", lrealm, DEFAULT_TKT_LIFE, passw);
