@@ -209,7 +209,7 @@ login(char *host)
 		char prompt[128];
 		if(myname && 
 		   (!strcmp(user, "ftp") || !strcmp(user, "anonymous"))){
-		    sprintf(defaultpass, "%s@%s", myname, mydomain+1);
+		    sprintf(defaultpass, "%s@%s", myname, mydomain);
 		    sprintf(prompt, "Password (%s): ", defaultpass);
 		}else{
 		    strcpy(defaultpass, "");
@@ -224,7 +224,8 @@ login(char *host)
 	}
 	if (n == CONTINUE) {
 		aflag++;
-		acct = getpass("Account:");
+		acct = malloc(128); /* XXX */
+		des_read_pw_string(acct, 128, "Account:", 0);
 		n = command("ACCT %s", acct);
 	}
 	if (n != COMPLETE) {
@@ -507,13 +508,13 @@ getreply(int expecteof)
 #endif
 
 int
-empty(struct fd_set *mask, int sec)
+empty(fd_set *mask, int sec)
 {
 	struct timeval t;
 
 	t.tv_sec = (long) sec;
 	t.tv_usec = 0;
-	return (select(32, mask, (struct fd_set *) 0, (struct fd_set *) 0, &t));
+	return (select(32, mask, (fd_set *) 0, (fd_set *) 0, &t));
 }
 
 jmp_buf	sendabort;
@@ -932,18 +933,23 @@ recvrequest(char *cmd, char *local, char *remote, char *lmode, int printnames)
 		}
 		closefunc = fclose;
 	}
-	if (fstat(fileno(fout), &st) < 0 || st.st_blksize == 0)
-		st.st_blksize = BUFSIZ;
-	if (st.st_blksize > bufsize) {
+	{
+	    size_t blocksize = BUFSIZ;
+#ifdef HAVE_ST_BLKSIZE
+	    if (fstat(fileno(fout), &st) >= 0 && st.st_blksize > 0)
+		blocksize = st.st_blksize;
+#endif
+	    if (blocksize > bufsize) {
 		if (buf)
-			(void) free(buf);
-		buf = malloc((unsigned)st.st_blksize);
+		    (void) free(buf);
+		buf = malloc(blocksize);
 		if (buf == NULL) {
-			warn("malloc");
-			bufsize = 0;
-			goto abort;
+		    warn("malloc");
+		    bufsize = 0;
+		    goto abort;
 		}
-		bufsize = st.st_blksize;
+		bufsize = blocksize;
+	    }
 	}
 	(void) gettimeofday(&start, (struct timezone *)0);
 	switch (curtype) {
@@ -1397,7 +1403,7 @@ proxtrans(char *cmd, char *local, char *remote)
 	sighand oldintr;
 	int secndflag = 0, prox_type, nfnd;
 	char *cmd2;
-	struct fd_set mask;
+	fd_set mask;
 
 	if (strcmp(cmd, "RETR"))
 		cmd2 = "RETR";
@@ -1512,7 +1518,7 @@ abort:
 void
 reset(int argc, char **argv)
 {
-	struct fd_set mask;
+	fd_set mask;
 	int nfnd = 1;
 
 	FD_ZERO(&mask);
@@ -1579,7 +1585,7 @@ abort_remote(FILE *din)
 {
 	char buf[BUFSIZ];
 	int nfnd;
-	struct fd_set mask;
+	fd_set mask;
 
 	/*
 	 * send IAC in urgent mode instead of DM because 4.3BSD places oob mark
