@@ -61,11 +61,18 @@ int krb4_adat(char *auth)
   
     des_set_key(&auth_dat.session, schedule);
 
-    cs = htonl(auth_dat.checksum + 1);
-    len = krb_mk_safe(&cs, msg, sizeof(cs), &auth_dat.session, 
-		      &ctrl_addr, &his_addr);
+    cs = auth_dat.checksum + 1;
+    {
+	unsigned char tmp[4];
+	tmp[0] = (cs >> 24) & 0xff;
+	tmp[1] = (cs >> 16) & 0xff;
+	tmp[2] = (cs >> 8) & 0xff;
+	tmp[3] = cs & 0xff;
+	len = krb_mk_safe(tmp, msg, 4, &auth_dat.session, 
+			  &ctrl_addr, &his_addr);
+    }
     if(len < 0){
-	reply(535, "Error creating reply: %s.", k_strerror(errno));
+	reply(535, "Error creating reply: %s.", strerror(errno));
 	return -1;
     }
     base64_encode(msg, len, &p);
@@ -204,8 +211,12 @@ int krb4_read(int fd, void *data, int length)
     }
 
     while(length){
-	krb_net_read(fd, &len, 4);
-	len = ntohl(len);
+	unsigned char tmp[4];
+	if(krb_net_read(fd, tmp, 4) < 4){
+	    reply(400, "Unexpected end of file.\n");
+	    return -1;
+	}
+	len = (tmp[0] << 24) | (tmp[1] << 16) | (tmp[2] << 8) | tmp[3];
 	krb_net_read(fd, data_buffer, len);
 	if(data_protection == prot_safe)
 	    kerror = krb_rd_safe(data_buffer, len, &auth_dat.session, 
@@ -258,7 +269,7 @@ int krb4_write(int fd, void *data, int length)
 				&auth_dat.session,
 				&ctrl_addr, &his_addr);
 	if(bytes == -1){
-	    reply(535, "Failed to make packet: %s.", k_strerror(errno));
+	    reply(535, "Failed to make packet: %s.", strerror(errno));
 	    return -1;
 	}
 	data_buffer[0] = (bytes >> 24) & 0xff;
