@@ -1,6 +1,6 @@
 #include "kauth.h"
 
-RCSID("$Id: kauthd.c,v 1.5 1996/05/10 22:25:29 assar Exp $");
+RCSID("$Id: kauthd.c,v 1.6 1996/06/25 13:31:13 joda Exp $");
 
 static char name[SNAME_SZ + 1];
 static char inst[INST_SZ + 1];
@@ -113,8 +113,9 @@ doit(int sock)
      write_encrypted (sock, "ok", sizeof("ok") - 1, schedule,
 		      &auth.session, &thisaddr, &thataddr);
 
-     if (*tktfile)
-	  krb_set_tkt_string (tktfile);
+     if (*tktfile == 0)
+	 sprintf(tktfile, "%s%d", TKT_ROOT, getuid());
+     krb_set_tkt_string (tktfile);
 
      {
 	  struct remote_args arg;
@@ -142,5 +143,39 @@ doit(int sock)
 int
 main (int argc, char **argv)
 {
-     return doit(0);
+    int s = 0;
+    if(argc > 1 && strcmp(argv[1], "-i") == 0){
+	int s2;
+	int one = 1;
+	struct sockaddr_in sa;
+	s2 = socket(AF_INET, SOCK_STREAM, 0);
+	if(s2 < 0){
+	    perror("socket");
+	    exit(1);
+	}
+	memset(&sa, 0, sizeof(sa));
+	sa.sin_family = AF_INET;
+	sa.sin_port = k_getportbyname("kauth", "tcp", htons(2120));
+	
+	if(setsockopt(s2, SOL_SOCKET, SO_REUSEADDR, &one, sizeof(one)) < 0){
+	    perror("setsockopt");
+	    exit(1);
+	}
+
+	if(bind(s2, (struct sockaddr*)&sa, sizeof(sa)) < 0){
+	    perror("bind");
+	    exit(1);
+	}
+	if(listen(s2, 5) < 0){
+	    perror("listen");
+	    exit(1);
+	}
+	s = accept(s2, NULL, 0);
+	if(s < 0){
+	    perror("accept");
+	    exit(1);
+	}
+	close(s2);
+    }
+    return doit(s);
 }
