@@ -4,12 +4,13 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
+#if 0
 static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
 static char SccsId[] = "@(#)@(#)pop_init.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
 #include <popper.h>
+RCSID("$Id: pop_init.c,v 1.13 1996/06/15 16:58:41 assar Exp $");
 
 #ifdef KERBEROS
 AUTH_DAT kdata;
@@ -21,6 +22,48 @@ AUTH_DAT kdata;
 
 extern int      errno;
 
+static
+int
+krb_authenticate(POP *p, struct sockaddr_in *addr)
+{
+
+#ifdef KERBEROS
+    Key_schedule schedule;
+    KTEXT_ST ticket;
+    char instance[INST_SZ];  
+    char version[9];
+    int auth;
+  
+    strcpy(instance, "*");
+    auth = krb_recvauth(0L, 0, &ticket, "pop", instance,
+                        addr, (struct sockaddr_in *) NULL,
+                        &kdata, "", schedule, version);
+    
+    if (auth != KSUCCESS) {
+        pop_msg(p, POP_FAILURE, "Kerberos authentication failure: %s", 
+                krb_get_err_text(auth));
+        pop_log(p, POP_FAILURE, "%s: (%s.%s@%s) %s", p->client, 
+                kdata.pname, kdata.pinst, kdata.prealm, krb_get_err_text(auth));
+        exit(-1);
+    }
+
+#ifdef DEBUG
+    pop_log(p, POP_DEBUG, "%s.%s@%s (%s): ok", kdata.pname, 
+            kdata.pinst, kdata.prealm, inet_ntoa(addr->sin_addr));
+#endif /* DEBUG */
+
+#endif /* KERBEROS */
+
+    return(POP_SUCCESS);
+}
+
+static
+int
+plain_authenticate (POP *p, struct sockaddr_in *addr)
+{
+    return(POP_SUCCESS);
+}
+
 /* 
  *  init:   Start a Post Office Protocol session
  */
@@ -40,13 +83,13 @@ pop_init(POP *p,int argcount,char **argmessage)
     char                *   trace_file_name;
 
     /*  Initialize the POP parameter block */
-    bzero ((char *)p,(int)sizeof(POP));
+    memset (p,0, sizeof(POP));
 
     /*  Save my name in a global variable */
     p->myname = argmessage[0];
 
     /*  Get the name of our host */
-    (void)gethostname(p->myhost,MAXHOSTNAMELEN);
+    (void)gethostname(p->myhost,MaxHostNameLen);
 
     /*  Open the log file */
 #ifdef SYSLOG42
@@ -56,7 +99,11 @@ pop_init(POP *p,int argcount,char **argmessage)
 #endif
 
     /*  Process command line arguments */
-    while ((c = getopt(argcount,argmessage,"dt:")) != EOF)
+    while ((c = getopt(argcount,argmessage,
+#ifdef KERBEROS
+		       "k"
+#endif
+		       "dt:")) != EOF)
         switch (c) {
 
             /*  Debugging requested */
@@ -77,6 +124,13 @@ pop_init(POP *p,int argcount,char **argmessage)
                 trace_file_name = optarg;
                 break;
 
+#ifdef KERBEROS
+	    /* Use kerberos version of POP3 protocol */
+	    case 'k':
+		p->kerberosp = 1;
+		break;
+#endif
+
             /*  Timeout value passed.  Default changed */
             case 'T':
                 pop_timeout = atoi(optarg);
@@ -118,21 +172,10 @@ pop_init(POP *p,int argcount,char **argmessage)
     /*  Save the cannonical name of the client host in 
         the POP parameter block */
     else {
-
-#ifndef BIND43
-        p->client = ch->h_name;
-#else
-#       include <arpa/nameser.h>
-#       include <resolv.h>
-
         /*  Distrust distant nameservers */
-        extern struct state     _res;
         struct hostent      *   ch_again;
         char            *   *   addrp;
 
-        /*  We already have a fully-qualified name */
-        _res.options &= ~RES_DEFNAMES;
-
         /*  See if the name obtained for the client's IP 
             address returns an address */
         if ((ch_again = gethostbyname(ch->h_name)) == NULL) {
@@ -149,7 +192,9 @@ pop_init(POP *p,int argcount,char **argmessage)
             /*  Look for the client's IP address in the list returned 
                 for its name */
             for (addrp=ch_again->h_addr_list; *addrp; ++addrp)
-                if (bcmp(*addrp,&(cs.sin_addr),sizeof(cs.sin_addr)) == 0) break;
+	        if (memcmp(*addrp, &cs.sin_addr, sizeof(cs.sin_addr))
+		    == 0)
+		  break;
 
             if (!*addrp) {
                 pop_log (p,POP_PRIORITY,
@@ -158,7 +203,6 @@ pop_init(POP *p,int argcount,char **argmessage)
                 p->client = p->ipaddr;
             }
         }
-#endif /* BIND43 */
     }
 
     /*  Create input file stream for TCP/IP communication */
@@ -188,39 +232,5 @@ pop_init(POP *p,int argcount,char **argmessage)
         pop_log(p,POP_PRIORITY,"Debugging turned on");
 #endif /* DEBUG */
 
-    return(authenticate(p, &cs));
-}
-
-int
-authenticate(POP *p, struct sockaddr_in *addr)
-{
-
-#ifdef KERBEROS
-    Key_schedule schedule;
-    KTEXT_ST ticket;
-    char instance[INST_SZ];  
-    char version[9];
-    int auth;
-  
-    strcpy(instance, "*");
-    auth = krb_recvauth(0L, 0, &ticket, "pop", instance,
-                        addr, (struct sockaddr_in *) NULL,
-                        &kdata, "", schedule, version);
-    
-    if (auth != KSUCCESS) {
-        pop_msg(p, POP_FAILURE, "Kerberos authentication failure: %s", 
-                krb_get_err_text(auth));
-        pop_log(p, POP_FAILURE, "%s: (%s.%s@%s) %s", p->client, 
-                kdata.pname, kdata.pinst, kdata.prealm, krb_get_err_text(auth));
-        exit(-1);
-    }
-
-#ifdef DEBUG
-    pop_log(p, POP_DEBUG, "%s.%s@%s (%s): ok", kdata.pname, 
-            kdata.pinst, kdata.prealm, inet_ntoa(addr->sin_addr));
-#endif /* DEBUG */
-
-#endif /* KERBEROS */
-
-    return(POP_SUCCESS);
+    return((p->kerberosp ? krb_authenticate : plain_authenticate)(p, &cs));
 }
