@@ -4,14 +4,13 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#ifndef lint
+#if 0
 static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
 static char SccsId[] = "@(#)@(#)popper.c	2.1  2.1 3/18/91";
 #endif /* not lint */
 
 #include <popper.h>
-
-extern  state_table *   pop_get_command();
+RCSID("$Id: popper.c,v 1.9 1996/06/15 16:59:00 assar Exp $");
 
 int hangup = FALSE ;
 
@@ -118,26 +117,3 @@ main (int argc, char **argv)
 
     return(0);
 }
-
-#ifdef STRNCASECMP
-/*
- *  Perform a case-insensitive string comparision
- */
-int
-strncasecmp(char *str1, char *str2,int len)
-{
-    register int    i;
-    char            a,
-                    b;
-
-    for (i=len-1;i>=0;i--){
-        a = str1[i];
-        b = str2[i];
-        if (isupper(a)) a = tolower(str1[i]);
-        if (isupper(b)) b = tolower(str2[i]);
-        if (a > b) return (1);
-        if (a < b) return(-1);
-    }
-    return(0);
-}
-#endif /* STRNCASECMP */
