@@ -1,4 +1,4 @@
-/* $Id: kx.h,v 1.4 1996/05/05 01:16:58 assar Exp $ */
+/* $Id: kx.h,v 1.6 1996/06/15 22:26:06 assar Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -11,6 +11,7 @@
 #include <errno.h>
 #include <pwd.h>
 #include <signal.h>
+#include <syslog.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #ifdef HAVE_SYS_RESOURCE_H
@@ -38,6 +39,10 @@
 #define SOMAXCONN 5
 #endif
 
+#ifndef LOG_DAEMON
+#define openlog(id,option,facility) openlog((id),(option))
+#endif
+
 extern char *prog;
 
 int copy_encrypted (int fd1, int fd2, des_cblock *iv,
