@@ -39,10 +39,6 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include <sys/socket.h>
 #include <pop.h>
 
-#ifndef HAVE_MEMMOVE
-#define memmove(a,b,c) bcopy((b),(a),(c))
-#endif /* HAVE_MEMMOVE */
-
 #ifdef HESIOD
 #include <hesiod.h>
 /*
