@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: commands.c,v 1.12 1996/05/13 02:02:12 joda Exp $");
+RCSID("$Id: commands.c,v 1.14 1996/08/04 23:09:01 joda Exp $");
 
 #include <sys/param.h>
 #include <sys/types.h>
@@ -1417,10 +1417,9 @@ static int bye(int argc, char **argv)
 	/* reset options */
 	tninit();
     }
-    if ((argc != 2) || (strcmp(argv[1], "fromquit") != 0)) {
+    if ((argc != 2) || (strcmp(argv[1], "fromquit") != 0)) 
 	longjmp(toplevel, 1);
-	/* NOTREACHED */
-    }
+    return 0;	/* NOTREACHED */
 }
 
 /*VARARGS*/
@@ -1428,7 +1427,7 @@ int quit(void)
 {
 	(void) call(bye, "bye", "fromquit", 0);
 	Exit(0);
-	/*NOTREACHED*/
+	return 0; /*NOTREACHED*/
 }
 
 /*VARARGS*/
@@ -1631,6 +1630,10 @@ env_find(var)
 	return(NULL);
 }
 
+#if IRIX == 4
+#define environ _environ
+#endif
+
 	void
 env_init()
 {
