@@ -33,7 +33,7 @@
 
 #include <config.h>
 
-RCSID("$Id: sys_bsd.c,v 1.7 1996/02/04 14:55:20 d91-jda Exp $");
+RCSID("$Id: sys_bsd.c,v 1.8 1996/05/13 01:49:40 joda Exp $");
 
 /*
  * The following routines try to encapsulate what is system dependent
@@ -124,9 +124,9 @@ TerminalWrite(char *buf, int n)
 }
 
 int
-TerminalRead(char *buf, int n)
+TerminalRead(unsigned char *buf, int n)
 {
-    return read(tin, buf, n);
+    return read(tin, (char*)buf, n);
 }
 
 /*
