@@ -121,6 +121,18 @@
 # define	TIOCSCTTY TCSETCTTY
 #endif
 
+#ifndef TIOCPKT_FLUSHWRITE
+#define TIOCPKT_FLUSHWRITE      0x02
+#endif
+ 
+#ifndef TIOCPKT_NOSTOP
+#define TIOCPKT_NOSTOP  0x10
+#endif
+ 
+#ifndef TIOCPKT_DOSTOP
+#define TIOCPKT_DOSTOP  0x20
+#endif
+
 #ifndef	FD_SET
 #ifndef	HAVE_fd_set
 typedef struct fd_set { int fds_bits[1]; } fd_set;
