@@ -1,7 +1,7 @@
 /*
  * Add here functions that don't have a prototype on your system.
  *
- * $Id: protos.h,v 1.20 1996/06/12 21:28:37 bg Exp $
+ * $Id: protos.h,v 1.21 1996/08/04 20:35:48 joda Exp $
  *
  */
 
@@ -98,16 +98,18 @@ int gettimeofday(struct timeval *tp, void *);
 
 #if defined(__osf__) /* OSF/1 */
 
+#if 0
 /* To get type fd_set */
 #include <sys/types.h>
 #include <sys/time.h>
 
 int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
-int flock(int fildes, int operation);
 int fsync(int fildes);
-/* int setreuid(int ruid, int euid); */
 int gethostname(char *address, int address_len);
+int setreuid(int ruid, int euid);
 int ioctl(int d, unsigned long request, void * arg);
+#endif
+int flock(int fildes, int operation);
 int syscall(int, ...);
 
 unsigned short htons(unsigned short hostshort);
@@ -123,7 +125,7 @@ int rresvport (int *port);
 
 #endif /* OSF/1 */
 
-#if defined(__GNUC__) && defined(__sgi__) /* IRIX */
+#if defined(__sgi__) && (defined(__GNUC__) || defined(__SVR3)) /* IRIX */
 
 char *crypt(const char *key, const char *salt);
 char *ptsname(int fd);
