@@ -36,7 +36,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadmin.c,v 1.26 1996/06/14 09:44:41 assar Exp $");
+RCSID("$Id: kadmin.c,v 1.29 1996/07/02 09:48:33 bg Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -119,7 +119,7 @@ static void
 get_expdate(Kadm_vals *vals)
 {
     char buff[BUFSIZ];
-    time_t when=0;
+    int ok = 0;
     struct tm edate;
 
     memset(&edate, 0, sizeof(edate));
@@ -136,11 +136,11 @@ get_expdate(Kadm_vals *vals)
             edate.tm_mon--;     /* January is 0, not 1 */
             edate.tm_hour = 23; /* nearly midnight at the end of the */
             edate.tm_min = 59;  /* specified day */
-            when = maketime(&edate, 1);
         }
-    } while (when <= 0);
+    } while (krb_check_tm (edate));
 
-    vals->exp_date = when;
+    edate.tm_year -= 1900;
+    vals->exp_date = tm2time (edate, 1);
     SET_FIELD(KADM_EXPDATE,vals->fields);
 }
 
@@ -307,7 +307,7 @@ do_init(int argc, char **argv)
      * about failure.
      */
     if (krb_get_lrealm(default_realm, 1) != KSUCCESS)
-      strcpy(default_realm, "NO.DEFAULT.REALM");
+      strcpy(default_realm, KRB_REALM);
     else if (krbrlm[0] == 0)
       strcpy(krbrlm, default_realm);
 
@@ -350,13 +350,9 @@ do_init(int argc, char **argv)
       usage();
     if (!myname[0]) {
 	char n[ANAME_SZ], i[INST_SZ], r[REALM_SZ];
-	if(krb_get_default_principal(n, i, r) >= 0){
+	if (krb_get_default_principal(n, i, r) >= 0) {
 	    strcpy(myname, n);
-	    if(*i)
-		strcpy(myinst, i);
-	    if(*r)
-		strcpy(myrealm, r);
-	}else{
+	} else {
 	    pw = getpwuid((int) getuid());
 	    if (!pw) {
 		fprintf(stderr,
@@ -616,22 +612,35 @@ add_new_key(int argc, char **argv)
     SET_FIELD(KADM_DESKEY,new.fields);
 
     if (princ_exists(new.name, new.instance, krbrlm) != PE_YES) {
+	Kadm_vals vals;
+	u_char fields[4];
+	char n[ANAME_SZ + INST_SZ + 1];
+
 	/* get the admin's password */
 	if (get_admin_password() != GOOD_PW)
 	    return;
 	
-	/* This is the default maximum lifetime for new principals. */
-	if (strcmp(new.instance, "admin") == 0)
-	  new.max_life = 1 + (CLOCK_SKEW/(5*60)); /* 5+5 minutes */
-	else if (strcmp(new.instance, "root") == 0)
-	  new.max_life = 96;	/* 8 hours */
-	else if (krb_life_to_time(0, 162) >= 24*60*60)
-	  new.max_life = 162;     /* ca 100 hours */
-	else
-	  new.max_life = 255;     /* ca 21 hours (maximum) */
+	memset(fields, 0, sizeof(fields));
+	SET_FIELD(KADM_NAME,fields);
+	SET_FIELD(KADM_INST,fields);
+	SET_FIELD(KADM_EXPDATE,fields);
+	SET_FIELD(KADM_ATTR,fields);
+	SET_FIELD(KADM_MAXLIFE,fields);
+	sprintf (n, "default.%s", new.instance);
+	if (setvals(&vals, n) != KADM_SUCCESS)
+	    return;
 
-	new.exp_date = time(0) + 2*(365*24*60*60); /* + ca 2 years */
-	new.attributes = 0;
+	if (kadm_get(&vals, fields) != KADM_SUCCESS) {
+	    if (setvals(&vals, "default") != KADM_SUCCESS)
+		return;
+	    if ((status = kadm_get(&vals, fields)) != KADM_SUCCESS) {
+		printf ("kadm error: %s\n", error_message(status));
+		return;
+	    }
+	}
+	new.max_life = vals.max_life;
+	new.exp_date = vals.exp_date;
+	new.attributes = vals.attributes;
 	get_maxlife(&new);
 	get_attr(&new);
 	get_expdate(&new);
