@@ -1,7 +1,7 @@
 /*
  * This software may now be redistributed outside the US.
  *
- * $Id: ksrvutil.c,v 1.24 1996/06/14 09:44:55 assar Exp $
+ * $Id: ksrvutil.c,v 1.25 1996/07/02 09:48:37 bg Exp $
  *
  */
 
@@ -353,7 +353,7 @@ main(int argc, char **argv)
 
     /* This is used only as a default for adding keys */
     if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
-	(void) strcpy(local_realm, "NO.DEFAULT.REALM");
+	(void) strcpy(local_realm, KRB_REALM);
     
     while((c = getopt(argc, argv, "ikc:f:p:r:")) != EOF) {
 	 switch (c) {
