@@ -1,7 +1,7 @@
 #include "kadm_locl.h"
 #include "ksrvutil.h"
 
-RCSID("$Id: ksrvutil_get.c,v 1.15 1996/06/16 00:19:41 assar Exp $");
+RCSID("$Id: ksrvutil_get.c,v 1.17 1996/08/04 15:34:24 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -158,13 +158,6 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   values.key_high = (newkey[4] << 24) | (newkey[5] << 16)
     | (newkey[6] << 8) | (newkey[7] << 0);
 
-#if 0
-  memcpy(&values.key_low, newkey, 4);
-  memcpy(&values.key_high, ((char *)newkey) + 4, 4);
-  values.key_low = htonl(values.key_low);
-  values.key_high = htonl(values.key_high);
-#endif
-
   SET_FIELD(KADM_NAME,values.fields);
   SET_FIELD(KADM_INST,values.fields);
   SET_FIELD(KADM_DESKEY,values.fields);
@@ -174,7 +167,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
     ret = kadm_add(&values);
   if (ret != KSUCCESS) {
     fprintf(stderr, "%s: Couldn't get srvtab entry for %s.%s: %s\n",
-	    progname, name, inst, krb_get_err_text(ret));
+	    progname, name, inst, error_message(ret));
     return;
   }
   
@@ -270,7 +263,7 @@ ksrvutil_get(int fd, char *filename, int argc, char **argv)
   int i;
 
   if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
-    strcpy(local_realm, "NO.DEFAULT.REALM");
+    strcpy(local_realm, KRB_REALM);
   k_gethostname(local_hostname, sizeof(local_hostname));
   strcpy(local_hostname, krb_get_phost(local_hostname));
 
@@ -333,7 +326,6 @@ ksrvutil_get(int fd, char *filename, int argc, char **argv)
   {
     struct srv_ent *p=head, *q;
     while(p){
-      printf("%s.%s@%s\n", p->name, p->inst, p->realm);
       q=p;
       p=p->next;
       free(q);
