@@ -19,21 +19,22 @@
 
 #include "kuser_locl.h"
 
-RCSID("$Id: kinit.c,v 1.8 1996/03/25 13:11:34 bg Exp $");
+RCSID("$Id: kinit.c,v 1.10 1996/05/31 20:59:51 assar Exp $");
 
 #define	LIFE	DEFAULT_TKT_LIFE /* lifetime of ticket in 5-minute units */
+#define CHPASSLIFE 2
 
 char   *progname;
 
 static void
 get_input(char *s, int size, FILE *stream)
 {
-	char *p;
+    char *p;
 
-	if (fgets(s, size, stream) == NULL)
-	  exit(1);
-	if ( (p = strchr(s, '\n')) != NULL)
-		*p = '\0';
+    if (fgets(s, size, stream) == NULL)
+	exit(1);
+    if ( (p = strchr(s, '\n')) != NULL)
+	*p = '\0';
 }
 
 
@@ -51,10 +52,11 @@ main(int argc, char **argv)
     char    inst[INST_SZ];
     char    realm[REALM_SZ];
     char    buf[MaxHostNameLen];
+    char    name[MAX_K_NAME_SZ];
     char   *username = NULL;
     int     iflag, rflag, vflag, lflag, pflag, lifetime, k_errno;
-    register char *cp;
-    register i;
+    char   *cp;
+    int	    i;
 
     *inst = *realm = '\0';
     iflag = rflag = vflag = lflag = pflag = 0;
@@ -84,7 +86,7 @@ main(int argc, char **argv)
 		continue;
 	    case 'p':
 		++pflag;	/* chpass-tickets */
-		lifetime = 2;	/* XXX */
+		lifetime = CHPASSLIFE;
 		break;
 	    default:
 		usage();
@@ -113,13 +115,12 @@ main(int argc, char **argv)
     } else {
 	printf("Kerberos Initialization\n");
 	printf("Kerberos name: ");
-	get_input(aname, sizeof(aname), stdin);
-	if (!*aname)
-	    exit(0);
-	if (!k_isname(aname)) {
-	    fprintf(stderr, "%s: bad Kerberos name format\n",
-		    progname);
-	    exit(1);
+	get_input(name, sizeof(name), stdin);
+	if (!*name)
+	    return 0;
+	if ((k_errno = kname_parse(aname, inst, realm, name)) != KSUCCESS ) {
+	    fprintf (stderr, "%s: %s\n", progname, krb_get_err_text(k_errno));
+	    return 1;
 	}
     }
     /* optional instance */
