@@ -34,7 +34,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_cli_wrap.c,v 1.11 1996/03/25 13:10:26 bg Exp $");
+RCSID("$Id: kadm_cli_wrap.c,v 1.14 1996/06/10 01:13:18 joda Exp $");
 
 #ifndef NULL
 #define NULL 0
@@ -52,8 +52,8 @@ static des_key_schedule sess_sched;
 static void
 clear_secrets(void)
 {
-	bzero((char *)sess_key, sizeof(sess_key));
-	bzero((char *)sess_sched, sizeof(sess_sched));
+	memset(sess_key, 0, sizeof(sess_key));
+	memset(sess_sched, 0, sizeof(sess_sched));
 	return;
 }
 
@@ -96,7 +96,7 @@ kadm_init_link(char *n, char *i, char *r)
 	if ((hop = gethostbyname(adm_hostname)) == NULL)
 		return KADM_UNK_HOST;  /* couldnt find the admin servers
 				        * address */
-	bzero((char *) &client_parm.admin_addr,
+	memset(&client_parm.admin_addr, 0,
 	      sizeof(client_parm.admin_addr));
 	if ((sep = getservbyname(KADM_SNAME, "tcp")) == NULL){
 	  fprintf(stderr, "Warning: %s/tcp service not found.\n", KADM_SNAME);
@@ -104,8 +104,7 @@ kadm_init_link(char *n, char *i, char *r)
 	}else
 	  client_parm.admin_addr.sin_port = sep->s_port;
 	client_parm.admin_addr.sin_family = hop->h_addrtype;
-	bcopy((char *) hop->h_addr, (char *) &client_parm.admin_addr.sin_addr,
-	      hop->h_length);
+	memcpy(&client_parm.admin_addr.sin_addr, hop->h_addr, hop->h_length);
 
 	return KADM_SUCCESS;
 }				       /* procedure kadm_init_link */
@@ -159,10 +158,10 @@ kadm_cli_keyd(des_cblock (*s_k), struct des_ks_struct *s_s)
 	if ((stat = krb_get_cred(client_parm.sname, client_parm.sinst,
 				client_parm.krbrlm, &cred)))
 		return stat + krb_err_base;
-	bcopy((char *) cred.session, (char *) s_k, sizeof(des_cblock));
-	bzero((char *) cred.session, sizeof(des_cblock));
+	memcpy(s_k, cred.session, sizeof(des_cblock));
+	memset(cred.session, 0, sizeof(des_cblock));
 #ifdef NOENCRYPTION
-	bzero(s_s, sizeof(des_key_schedule));
+	memset(s_s, 0, sizeof(des_key_schedule));
 #else
 	if ((stat = des_key_sched(s_k,s_s)))
 		return(stat+krb_err_base);
@@ -175,29 +174,30 @@ kadm_cli_out(u_char *dat, int dat_len, u_char **ret_dat, int *ret_siz)
 {
 	u_int16_t dlen;
 	int retval;
+	char tmp[4];
 
 	dlen = (u_int16_t) dat_len;
 
 	if (dat_len != (int)dlen)
 		return (KADM_NO_ROOM);
 
-	dlen = htons(dlen);
-	if (krb_net_write(client_parm.admin_fd, (char *) &dlen,
-			  sizeof(u_int16_t)) < 0)
-		return (errno);	       /* XXX */
+	tmp[0] = (dlen >> 8) & 0xff;
+	tmp[1] = dlen & 0xff;
+	if (krb_net_write(client_parm.admin_fd, tmp, 2) != 2)
+	    return (errno);	       /* XXX */
 
 	if (krb_net_write(client_parm.admin_fd, (char *) dat, dat_len) < 0)
 		return (errno);	       /* XXX */
 
-	if ((retval = krb_net_read(client_parm.admin_fd, (char *) &dlen,
-				  sizeof(u_int16_t)) != sizeof(u_int16_t))) {
+	
+	if ((retval = krb_net_read(client_parm.admin_fd, tmp, 2)) != 2){
 	    if (retval < 0)
 		return(errno);		/* XXX */
 	    else
 		return(EPIPE);		/* short read ! */
 	}
+	dlen = (tmp[0] << 8) | tmp[1];
 
-	dlen = ntohs(dlen);
 	*ret_dat = (u_char *)malloc((unsigned)dlen);
 	if (!*ret_dat)
 	    return(KADM_NOMEM);
@@ -288,10 +288,9 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 	    free((char *)priv_pak);
 	    return(KADM_NOMEM);
 	}
-	bcopy((char *) authent.dat, (char *) act_st + act_len, authent.length);
-	bcopy((char *) priv_pak, (char *) act_st + act_len + authent.length,
-	      priv_len);
-	free((char *)priv_pak);
+	memcpy((char *)act_st + act_len, authent.dat, authent.length);
+	memcpy((char *)act_st + act_len + authent.length, priv_pak, priv_len);
+	free(priv_pak);
 	if ((retdat = kadm_cli_out(act_st,
 				   act_len + authent.length + priv_len,
 				   ret_dat, ret_siz)) != KADM_SUCCESS)
@@ -302,13 +301,12 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 	/* first see if it's a YOULOUSE */
 	if ((*ret_siz >= KADM_VERSIZE) &&
 	    !strncmp(KADM_ULOSE, (char *)*ret_dat, KADM_VERSIZE)) {
-	    u_int32_t errcode;
+	    unsigned char *p;
 	    /* it's a youlose packet */
-	    if (*ret_siz < KADM_VERSIZE + sizeof(u_int32_t))
+	    if (*ret_siz < KADM_VERSIZE + 4)
 		RET_N_FREE2(KADM_BAD_VER);
-	    bcopy((char *)(*ret_dat) + KADM_VERSIZE, (char *)&errcode,
-		  sizeof(u_int32_t));
-	    retdat = (int) ntohl(errcode);
+	    p = (*ret_dat)+KADM_VERSIZE;
+	    retdat = (p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3];
 	    RET_N_FREE2(retdat);
 	}
 	/* need to decode the ret_dat */
@@ -322,22 +320,23 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 	if (strncmp((char *)mdat.app_data, KADM_VERSTR, KADM_VERSIZE))
 	    /* bad version */
 	    RET_N_FREE2(KADM_BAD_VER);
-	bcopy((char *)mdat.app_data+KADM_VERSIZE,
-	      (char *)&retdat, sizeof(u_int32_t));
-	retdat = ntohl((u_int32_t)retdat);
 	{
-	  int s=mdat.app_length - KADM_VERSIZE - sizeof(u_int32_t);
+	    unsigned char *p = mdat.app_data+KADM_VERSIZE;
+	    retdat = (p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3];
+	}
+	{
+	  int s=mdat.app_length - KADM_VERSIZE - 4;
 	  if(s<=0) s=1;
 	  if (!(return_dat = (u_char *)malloc(s)))
 	    RET_N_FREE2(KADM_NOMEM);
 	}
-	bcopy((char *) mdat.app_data + KADM_VERSIZE + sizeof(u_int32_t),
-	      (char *)return_dat,
-	      (int)mdat.app_length - KADM_VERSIZE - sizeof(u_int32_t));
-	free((char *)*ret_dat);
+	memcpy(return_dat,
+	       (char *) mdat.app_data + KADM_VERSIZE + 4,
+	       mdat.app_length - KADM_VERSIZE - 4);
+	free(*ret_dat);
 	clear_secrets();
 	*ret_dat = return_dat;
-	*ret_siz = mdat.app_length - KADM_VERSIZE - sizeof(u_int32_t);
+	*ret_siz = mdat.app_length - KADM_VERSIZE - 4;
 	return retdat;
 }
 
@@ -369,13 +368,10 @@ int kadm_change_pw_plain(unsigned char *newkey, char *password, char **pw_msg)
 
 	/* change key to stream */
 
-	bcopy(newkey+4, (char*)&keytmp, 4);
-	keytmp=ntohl(keytmp);
-	stsize += vts_long(keytmp, &send_st, stsize);
-
-	bcopy(newkey, (char*)&keytmp, 4);
-	keytmp=ntohl(keytmp);
-	stsize += vts_long(keytmp, &send_st, stsize);
+	send_st = realloc(send_st, stsize + 8);
+	memcpy(send_st + stsize + 4, newkey, 4); /* yes, this is backwards */
+	memcpy(send_st + stsize, newkey + 4, 4);
+	stsize += 8;
 	
 	if(password && *password)
 	  stsize += vts_string(password, &send_st, stsize);
@@ -435,7 +431,7 @@ kadm_add(Kadm_vals *vals)
 	st_len = vals_to_stream(vals, &st);
 	st2 = (u_char *) malloc((unsigned)(1 + st_len));
 	*st2 = (u_char) ADD_ENT;       /* here's the opcode */
-	bcopy((char *) st, (char *) st2 + 1, st_len);	/* append st on */
+	memcpy((char *) st2 + 1, (char *) st, st_len);	/* append st on */
 	retc = kadm_cli_send(st2, st_len + 1, &ret_st, &ret_sz);
 	free((char *)st);
 	free((char *)st2);
@@ -475,11 +471,11 @@ kadm_mod(Kadm_vals *vals1, Kadm_vals *vals2)
 	st_len = vals_to_stream(vals1, &st);
 	st2 = (u_char *) malloc((unsigned)(1 + st_len));
 	*st2 = (u_char) MOD_ENT;       /* here's the opcode */
-	bcopy((char *) st, (char *) st2 + 1, st_len++);	/* append st on */
-	free((char *)st);
+	memcpy((char *)st2 + 1, st, st_len++); /* append st on */
+	free(st);
 	nlen = vals_to_stream(vals2, &st);
 	st2 = (u_char *) realloc((char *) st2, (unsigned)(st_len + nlen));
-	bcopy((char *) st, (char *) st2 + st_len, nlen); /* append st on */
+	memcpy((char *) st2 + st_len, (char *) st, nlen); /* append st on */
 	retc = kadm_cli_send(st2, st_len + nlen, &ret_st, &ret_sz);
 	free((char *)st);
 	free((char *)st2);
@@ -493,6 +489,30 @@ kadm_mod(Kadm_vals *vals1, Kadm_vals *vals2)
 	return(retc);
 }
 
+
+int
+kadm_del(Kadm_vals *vals)
+{
+    unsigned char *st, *st2;	       /* st will hold the stream of values */
+    int st_len;		       /* st2 the final stream with opcode */
+    int retc;		       /* return code from call */
+    u_char *ret_st;
+    int ret_sz;
+    
+    if ((retc = kadm_cli_conn()) != KADM_SUCCESS)
+	return(retc);
+    st_len = vals_to_stream(vals, &st);
+    st2 = (unsigned char *) malloc(st_len + 1);
+    *st2 = DEL_ENT;       /* here's the opcode */
+    memcpy(st2 + 1, st, st_len);	/* append st on */
+    retc = kadm_cli_send(st2, st_len + 1, &ret_st, &ret_sz);
+    free(st);
+    free(st2);
+    kadm_cli_disconn();
+    return(retc);
+}
+
+
 /*
  * kadm_get
  * 	receives   : KTEXT, {values, flags} 
@@ -518,7 +538,7 @@ kadm_get(Kadm_vals *vals, u_char *fl)
 	st_len = vals_to_stream(vals, &st);
 	st2 = (u_char *) malloc((unsigned)(1 + st_len + FLDSZ));
 	*st2 = (u_char) GET_ENT;       /* here's the opcode */
-	bcopy((char *) st, (char *) st2 + 1, st_len);	/* append st on */
+	memcpy((char *)st2 + 1, st, st_len); /* append st on */
 	for (loop = FLDSZ - 1; loop >= 0; loop--)
 		*(st2 + st_len + FLDSZ - loop) = fl[loop]; /* append the flags */
 	retc = kadm_cli_send(st2, st_len + 1 + FLDSZ,  &ret_st, &ret_sz);
