@@ -1,17 +1,27 @@
+/* $Id: kadm_locl.h,v 1.2 1996/05/31 20:59:55 assar Exp $ */
+
 #include "config.h"
 #include "protos.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <signal.h>
 #include <time.h>
 #include <errno.h>
 
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 
 #include <des.h>
 #include <krb.h>
