@@ -1,3 +1,5 @@
+/* $Id: afssysdefs.h,v 1.11 1996/08/04 22:32:44 assar Exp $ */
+
 /*
  * This section is for machines using single entry point AFS syscalls!
  * and/or
@@ -38,16 +40,11 @@
 #define AFS_SYSCALL	31
 #endif
 
-#if defined(__linux)
-#define AFS_SYSCALL	137
-/* Kent Engstrm <kent@lysator.liu.se> 1995-08-22
-   Linux has no SIGSYS signal. Furthermore, the normal
-   kernels have no support for AFS. I'm not sure about
-   what to do, but for now I use SIGILL instead of SIGSYS.
-*/
-#define SIGSYS SIGILL
-#endif /* __linux */
-
 #if defined(__NetBSD__)
 #define AFS_SYSCALL 210
 #endif
+
+#ifdef SYS_afs_syscall
+#undef  AFS_SYSCALL
+#define AFS_SYSCALL	SYS_afs_syscall
+#endif
