@@ -1,7 +1,5 @@
 /*
- * $Source: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v $
- * $Author: bg $
- * $Header: /afs/nada.kth.se/src/packages/kth-krb/SourceRepository/krb4/lib/kdb/krb_db.h,v 1.9 1996/03/28 11:10:47 bg Exp $ 
+ * $Id: krb_db.h,v 1.11 1996/06/12 21:28:57 bg Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -23,8 +21,11 @@
 #define KERB_M_INST		"M"	/* Master */
 #define KERB_DEFAULT_NAME	"default"
 #define KERB_DEFAULT_INST	""
+#ifndef DB_DIR
+#define DB_DIR			"/var/kerberos"
+#endif
 #ifndef DBM_FILE
-#define	DBM_FILE		"/var/kerberos/principal"
+#define	DBM_FILE		DB_DIR "/principal"
 #endif
 
 /* this also defines the number of queue headers */
