@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "kdb_locl.h"
 
-RCSID("$Id: krb_dbm.c,v 1.14 1996/05/03 23:14:59 assar Exp $");
+RCSID("$Id: krb_dbm.c,v 1.17 1996/06/11 01:45:34 assar Exp $");
 
 #ifdef NDBM
 #include <ndbm.h>
@@ -119,6 +119,7 @@ typedef char DBM;
 #define dbm_open(file, flags, mode) ((dbminit(file) == 0)?"":((char *)0))
 #define dbm_fetch(db, key) fetch(key)
 #define dbm_store(db, key, content, flag) store(key, content)
+#define dbm_delete(db, key) delete(key)
 #define dbm_firstkey(db) firstkey()
 #define dbm_next(db,key) nextkey(key)
 #define dbm_close(db) dbmclose()
@@ -171,7 +172,7 @@ encode_princ_contents(datum *contents, Principal *principal)
 static void
 decode_princ_contents (datum *contents, Principal *principal)
 {
-    bcopy(contents->dptr, (char *) principal, sizeof(*principal));
+    memcpy((char *) principal, contents->dptr, sizeof(*principal));
 }
 
 static void
@@ -179,7 +180,7 @@ encode_princ_key (datum *key, char *name, char *instance)
 {
     static char keystring[ANAME_SZ + INST_SZ];
 
-    bzero(keystring, ANAME_SZ + INST_SZ);
+    memset(keystring, 0, ANAME_SZ + INST_SZ);
     strncpy(keystring, name, ANAME_SZ);
     strncpy(&keystring[ANAME_SZ], instance, INST_SZ);
     key->dptr = keystring;
@@ -541,6 +542,42 @@ kerb_db_rename(char *from, char *to)
 	return -1;
 }
 
+int
+kerb_db_delete_principal (char *name, char *inst)
+{
+    DBM *db;
+    int try;
+    int done = 0;
+    int code;
+    datum key;
+    
+    if(!init)
+	kerb_db_init();
+    
+    for(try = 0; try < KERB_DB_MAX_RETRY; try++){
+	if((code = kerb_dbl_lock(KERB_DBL_SHARED)) != 0)
+	    return -1;
+	
+	db = dbm_open(current_db_name, O_RDWR, 0600);
+	if(db == NULL)
+	    return -1;
+	encode_princ_key(&key, name, inst);
+	if(dbm_delete(db, key) == 0)
+	    done = 1;
+	
+	dbm_close(db);
+	kerb_dbl_unlock();
+	if(done)
+	    break;
+	if(!non_blocking)
+	    sleep(1);
+    }
+    if(!done)
+	return -1;
+    return 0;
+}
+
+
 /*
  * look up a principal in the data base returns number of principals
  * found , and whether there were more than requested. 
@@ -769,7 +806,7 @@ delta_stat(DB_stat *a, DB_stat *b, DB_stat *c)
     c->n_get_stat = a->n_get_stat - b->n_get_stat;
     c->n_put_stat = a->n_put_stat - b->n_put_stat;
 
-    bcopy(a, b, sizeof(DB_stat));
+    memcpy(b, a, sizeof(DB_stat));
     return;
 }
 
