@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: create_ticket.c,v 1.6 1996/05/29 23:17:43 joda Exp $");
+RCSID("$Id: create_ticket.c,v 1.7 1996/06/17 15:57:32 joda Exp $");
 
 /*
  * Create ticket takes as arguments information that should be in a
@@ -78,7 +78,7 @@ krb_create_ticket(KTEXT tkt, unsigned char flags,
     p += put_int(flags, p, 1);
     p += put_nir(pname, pinstance, prealm, p);
     
-    p += put_int(ntohl(paddress), p, 4);
+    p += put_address(paddress, p);
     
     memcpy(p, session, 8);
     p += 8;
