@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: decomp_ticket.c,v 1.8 1996/05/22 17:34:01 joda Exp $");
+RCSID("$Id: decomp_ticket.c,v 1.10 1996/07/22 11:58:44 joda Exp $");
 
 /*
  * This routine takes a ticket and pointers to the variables that
@@ -36,14 +36,14 @@ decomp_ticket(KTEXT tkt, unsigned char *flags,
 	      u_int32_t *paddress, unsigned char *session, 
 	      int *life, u_int32_t *time_sec, 
 	      char *sname, char *sinstance, 
-	      des_cblock *key, struct des_ks_struct *key_s)
+	      des_cblock *key, des_key_schedule schedule)
 {
     unsigned char *p = tkt->dat;
     
     int little_endian;
 
     des_pcbc_encrypt((des_cblock *)tkt->dat, (des_cblock *)tkt->dat,
-		     tkt->length, key_s, key, DES_DECRYPT);
+		     tkt->length, schedule, key, DES_DECRYPT);
 
     *flags = *p++;
 
@@ -61,8 +61,7 @@ decomp_ticket(KTEXT tkt, unsigned char *flags,
 	return KFAILURE;
     p += get_string(p, prealm);
 
-    p += get_int(p, paddress, 4, 0); /* in correct order */
-    *paddress = htonl(*paddress);
+    p += get_address(p, paddress);
 
     memcpy(session, p, 8);
     p += 8;
