@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: get_krbrlm.c,v 1.7 1996/04/25 10:42:01 bg Exp $");
+RCSID("$Id: get_krbrlm.c,v 1.8 1996/08/04 16:42:43 assar Exp $");
 
 /*
  * krb_get_lrealm takes a pointer to a string, and a number, n.  It fills
@@ -90,6 +90,11 @@ krb_get_lrealm(char *r, int n)
     {
       char *t, hostname[MaxHostNameLen];
       k_gethostname(hostname, sizeof(hostname));
+      t = krb_realmofhost(hostname);
+      if (t) {
+	strcpy (r, t);
+	return KSUCCESS;
+      }
       t = strchr(hostname, '.');
       if (t == 0)
 	return KFAILURE;	/* No domain part, you loose */
