@@ -1,10 +1,10 @@
 #include "krb_locl.h"
 
-RCSID("$Id: k_name_to_name.c,v 1.5 1996/04/29 09:20:12 bg Exp $");
+RCSID("$Id: k_name_to_name.c,v 1.6 1996/05/13 01:59:25 joda Exp $");
 
 /* convert host to a more fully qualified domain name, returns 0 if
  * phost is the same as host, 1 otherwise. phost should be at least
- * MAXHOSTNAMELEN+1 bytes long
+ * MaxHostNameLen+1 bytes long
  */
 
 #ifndef INADDR_NONE
