@@ -1,5 +1,5 @@
 /*
- * $Id: krb.h,v 1.30 1996/06/14 09:44:31 assar Exp $
+ * $Id: krb.h,v 1.34 1996/07/23 14:21:09 assar Exp $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -23,6 +23,14 @@
 /* Need some defs from des.h	 */
 #include <des.h>
 
+/* Don't use these guys, they are only for compatibility with CNS. */
+#ifndef KRB_INT32
+#define KRB_INT32 int32_t
+#endif
+#ifndef KRB_UINT32
+#define KRB_UINT32 u_int32_t
+#endif
+
 /* Global library variables. */
 extern int krb_ignore_ip_address; /* To turn of IP address comparison */
 extern int krb_no_long_lifetimes; /* To disable AFS compatible lifetimes */
@@ -59,16 +67,25 @@ const char *krb_get_err_text __P((int code));
  */
 
 /* /etc/kerberosIV is only for backwards compatibility, don't use it! */
+#ifndef KRB_CONF
+#define KRB_CONF	"/etc/krb.conf"
+#endif
+#ifndef KRB_RLM_TRANS
+#define KRB_RLM_TRANS   "/etc/krb.realms"
+#endif
 #ifndef KRB_CNF_FILES
-#define KRB_CNF_FILES	{ "/etc/krb.conf",   "/etc/kerberosIV/krb.conf", 0}
+#define KRB_CNF_FILES	{ KRB_CONF,   "/etc/kerberosIV/krb.conf", 0}
 #endif
 #ifndef KRB_RLM_FILES
-#define KRB_RLM_FILES	{ "/etc/krb.realms", "/etc/kerberosIV/krb.realms", 0}
+#define KRB_RLM_FILES	{ KRB_RLM_TRANS, "/etc/kerberosIV/krb.realms", 0}
 #endif
 #ifndef KRB_EQUIV
 #define KRB_EQUIV	"/etc/krb.equiv"
 #endif
 #define KRB_MASTER	"kerberos"
+#ifndef KRB_REALM
+#define KRB_REALM	(krb_get_default_realm())
+#endif
 
 /* The maximum sizes for aname, realm, sname, and instance +1 */
 #define 	ANAME_SZ	40
@@ -426,8 +443,6 @@ typedef int (*decrypt_proc_t)(char*, char*, char*, void*,
 int krb_get_in_tkt __P((char*, char*, char*, char*, char*, int, key_proc_t, 
 			decrypt_proc_t, void*));
 int krb_get_krbhst __P((char *, char *, int));
-int krb_get_krbhst __P((char *, char *, int));
-int krb_get_krbhst __P((char *, char *, int));
 int krb_get_lrealm __P((char *, int));
 char *krb_get_default_realm __P((void));
 int krb_get_pw_in_tkt __P((char *, char *, char *, char *, char *, int, char *));
@@ -465,7 +480,8 @@ int krb_verify_user __P((char*, char*, char*, char*, int, char *));
 void kset_logfile __P((char *));
 void set_logfile __P((char *));
 
-void k_log __P((const char *format, ...));
+void krb_log __P((const char *format, ...));
+#define k_log krb_log
 
 int getst __P((int, char *, int));
 
