@@ -1,4 +1,4 @@
-/* $Id: krb_locl.h,v 1.10 1996/05/31 21:00:16 assar Exp $ */
+/* $Id: krb_locl.h,v 1.11 1996/07/04 22:09:47 joda Exp $ */
 
 #ifndef __krb_locl_h
 #define __krb_locl_h
@@ -60,6 +60,13 @@
 #include <netdb.h>
 #endif
 
+#ifdef HAVE_ARPA_NAMESER_H
+#include <arpa/nameser.h>
+#endif
+#ifdef HAVE_RESOLV_H
+#include <resolv.h>
+#endif
+
 #include <krb.h>
 #include <prot.h>
 
