@@ -26,9 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: mk_err.c,v 1.3 1996/03/25 13:09:42 bg Exp $");
-
-#include <sys/types.h>
+RCSID("$Id: mk_err.c,v 1.4 1996/05/15 03:39:46 joda Exp $");
 
 /*
  * This routine creates a general purpose error reply message.  It
@@ -52,25 +50,12 @@ RCSID("$Id: mk_err.c,v 1.3 1996/03/25 13:09:42 bg Exp $");
 
 int32_t
 krb_mk_err(u_char *p, int32_t e, char *e_string)
-              			/* Where to build error packet */
-           			/* Error code */
-                   		/* Text of error */
 {
-    u_char      *start;
-
-    start = p;
-
-    /* Create fixed part of packet */
-    *p++ = (unsigned char) KRB_PROT_VERSION;
-    *p = (unsigned char) AUTH_MSG_APPL_ERR;
-    *p++ |= HOST_BYTE_ORDER;
-
-    /* Add the basic info */
-    bcopy((char *)&e,(char *)p,4); /* err code */
-    p += sizeof(e);
-    (void) strcpy((char *)p,e_string); /* err text */
-    p += strlen(e_string);
-
-    /* And return the length */
-    return p-start;
+    unsigned char *start = p;
+    p += put_int(KRB_PROT_VERSION, p, 1);
+    p += put_int(AUTH_MSG_APPL_ERR, p, 1);
+    
+    p += put_int(e, p, 4);
+    p += put_string(e_string, p);
+    return p - start;
 }
