@@ -1,11 +1,11 @@
 #include "krb_locl.h"
 
-RCSID("$Id: mk_req.c,v 1.8 1996/05/31 21:00:18 assar Exp $");
+RCSID("$Id: mk_req.c,v 1.10 1996/08/04 22:55:56 assar Exp $");
 
 static int lifetime = 255;	/* But no longer than TGT says. */
 
 
-static int
+static void
 build_request(KTEXT req, char *name, char *inst, char *realm, 
 	      u_int32_t checksum)
 {
@@ -21,7 +21,7 @@ build_request(KTEXT req, char *name, char *inst, char *realm,
     gettimeofday(&tv, NULL);
 
     *p++ = tv.tv_usec / 5000; /* 5ms */
-
+    
     p += put_int(tv.tv_sec, p, 4);
 
     /* Fill to a multiple of 8 bytes for DES */
@@ -135,11 +135,7 @@ krb_mk_req(register KTEXT authent, char *service, char *instance, char *realm,
 
     build_request(req_id, cr.pname, cr.pinst, myrealm, checksum);
     
-    des_set_key(&cr.session, schedule);
-    des_pcbc_encrypt((des_cblock *)req_id->dat, (des_cblock *)req_id->dat,
-		     req_id->length, schedule, &cr.session, DES_ENCRYPT);
-
-    memset(schedule, 0, sizeof(schedule));
+    encrypt_ktext(req_id, &cr.session, DES_ENCRYPT);
 
     p += put_int(req_id->length, p, 1);
 
