@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: mk_safe.c,v 1.11 1996/05/15 03:39:48 joda Exp $");
+RCSID("$Id: mk_safe.c,v 1.13 1996/06/25 13:34:04 joda Exp $");
 
 /* application include files */
 #include "lsb_addr_comp.h"
@@ -62,9 +62,8 @@ krb_mk_safe(void *in, void *out, u_int32_t length, des_cblock *key,
 
     *p++ = tv.tv_usec/5000; /* 5ms */
     
-    /* see comment in rd_safe */
-    src_addr = htonl(sender->sin_addr.s_addr);
-    p += put_int(src_addr, p, 4);
+    src_addr = sender->sin_addr.s_addr;
+    p += put_address(src_addr, p);
 
     p += put_int(lsb_time(tv.tv_sec, sender, receiver), p, 4);
 
