@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: rd_priv.c,v 1.13 1996/05/15 03:39:50 joda Exp $");
+RCSID("$Id: rd_priv.c,v 1.16 1996/08/04 16:53:11 joda Exp $");
 
 /* application include files */
 #include "lsb_addr_comp.h"
@@ -62,12 +62,10 @@ krb_rd_priv(void *in, u_int32_t in_length,
     
     m_data->time_5ms = *p++;
 
-    p += get_int(p, &src_addr, 4, 0); /* don't swap */
-    /* see comment in rd_safe */
-    src_addr = htonl(src_addr);
+    p += get_address(p, &src_addr);
 
     if (!krb_equiv(src_addr, sender->sin_addr.s_addr))
-	return RD_AP_MODIFIED;
+	return RD_AP_BADD;
 
     p += get_int(p, &m_data->time_sec, 4, little_endian);
 
