@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: rd_safe.c,v 1.13 1996/05/15 03:39:54 joda Exp $");
+RCSID("$Id: rd_safe.c,v 1.15 1996/08/04 16:53:05 joda Exp $");
 
 /* application include files */
 #include "lsb_addr_comp.h"
@@ -60,16 +60,10 @@ krb_rd_safe(void *in, u_int32_t in_length, des_cblock *key,
 
     m_data->time_5ms = *p++;
 
-    p += get_int(p, &src_addr, 4, 0); 
-
-    /* addresses are always sent in network byteorder, but since
-       get_int makes right, we get this wrong on little endian
-       machines, so we must make right again */
-
-    src_addr = htonl(src_addr);
+    p += get_address(p, &src_addr);
 
     if (!krb_equiv(src_addr, sender->sin_addr.s_addr))
-        return RD_AP_MODIFIED;
+        return RD_AP_BADD;
 
     p += get_int(p, &m_data->time_sec, 4, little_endian);
     m_data->time_sec = lsb_time(m_data->time_sec, sender, receiver);
