@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: recvauth.c,v 1.8 1996/06/04 00:42:37 joda Exp $");
+RCSID("$Id: recvauth.c,v 1.9 1996/08/04 16:55:31 joda Exp $");
 
 /*
  * If the protocol changes, you will need to change the version string
@@ -120,8 +120,8 @@ RCSID("$Id: recvauth.c,v 1.8 1996/06/04 00:42:37 joda Exp $");
 static int
 send_error_reply(int fd)
 {
-    char tmp[4] = { 255, 255, 255, 255 };
-    if(krb_net_write(fd, tmp, 4) != 4)
+    unsigned char tmp[4] = { 255, 255, 255, 255 };
+    if(krb_net_write(fd, (char*)tmp, 4) != 4)
 	return -1;
     return 0;
 }
