@@ -1,6 +1,6 @@
 #include "krb_locl.h"
 
-RCSID("$Id: rw.c,v 1.1 1996/05/15 03:39:55 joda Exp $");
+RCSID("$Id: rw.c,v 1.2 1996/06/17 15:57:39 joda Exp $");
 
 int
 get_int(unsigned char *from, u_int32_t *to, int size, int lsb)
@@ -30,6 +30,23 @@ put_int(u_int32_t from, void *to, int size)
     return size;
 }
 
+
+/* addresses are always sent in network byte order */
+
+int
+get_address(void *from, u_int32_t *to)
+{
+    unsigned char *p = (unsigned char*)from;
+    *to = htonl((p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3]);
+    return 4;
+}
+
+int
+put_address(u_int32_t addr, void *to)
+{
+    return put_int(ntohl(addr), to, 4);
+}
+
 int
 put_string(char *from, char *to)
 {
