@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: send_to_kdc.c,v 1.15 1996/03/28 11:10:52 bg Exp $");
+RCSID("$Id: send_to_kdc.c,v 1.17 1996/06/01 01:27:37 assar Exp $");
 
 #define S_AD_SZ sizeof(struct sockaddr_in)
 
@@ -101,25 +101,15 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
       fprintf(stderr, "lrealm is %s\n", lrealm);
 #endif
     if (krb_udp_port == 0) {
-        register struct servent *sp;
-        if ((sp = getservbyname("kerberos","udp")) == 0) {
-#ifndef KRB_NDEB
-            if (krb_debug)
-                fprintf(stderr, "%s: Can't get kerberos/udp service\n",
-                        prog);
-#endif
-            krb_udp_port = htons(KRB_PORT); /* Was return(SKDC_CANT); */
-        }
-        else
-	    krb_udp_port = sp->s_port;
+        krb_udp_port = k_getportbyname ("kerberos", "udp", htons(KRB_PORT));
 #ifndef KRB_NDEB
         if (krb_debug)
 	  fprintf(stderr, "krb_udp_port is %d\n", krb_udp_port);
 #endif
     }
-    bzero((char *)&to, S_AD_SZ);
+    memset(&to, 0, S_AD_SZ);
     addrlist = malloc(sizeof(*addrlist));
-    bzero(addrlist, sizeof(*addrlist));
+    memset(addrlist, 0, sizeof(*addrlist));
     if (addrlist == NULL)
         return (SKDC_CANT);
     if ((f = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
@@ -158,10 +148,10 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
   	  addrlist = realloc(addrlist, sizeof(*addrlist) * (n_hosts+1));
 	  if (addrlist == NULL)
 	    return SKDC_CANT;
-	  bzero(&addrlist[n_hosts-1], sizeof(*addrlist));
+	  memset(&addrlist[n_hosts-1], 0, sizeof(*addrlist));
 	  addrlist[n_hosts-1].sin_family = host->h_addrtype;
 	  addrlist[n_hosts-1].sin_port   = krb_udp_port;
-	  bcopy(p, &addrlist[n_hosts-1].sin_addr, host->h_length);
+	  memcpy(&addrlist[n_hosts-1].sin_addr, p, host->h_length);
 	  if (send_recv(pkt, rpkt, f, &addrlist[n_hosts-1],
 			addrlist, n_hosts)) {
             retval = KSUCCESS;
@@ -257,7 +247,7 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
 #ifndef KRB_NDEB
         if (krb_debug) {
 	    long rfds;
-	    bcopy(&readfds, &rfds, sizeof(rfds));
+	    memcpy(&rfds, &readfds, sizeof(rfds));
             fprintf(stderr, "select failed: readfds=%lx",
                     rfds);
             perror("");
