@@ -1,6 +1,5 @@
 /*
- * $Source: /src/packages/kth-krb/SourceRepository/krb4/lib/krb/stime.c,v $
- * $Author: assar $
+ * $Id: stime.c,v 1.3 1996/05/31 21:00:24 assar Exp $
  *
  * Copyright 1985, 1986, 1987, 1988 by the Massachusetts Institute
  * of Technology.
@@ -11,7 +10,7 @@
 
 #include "krb_locl.h"
 
-#include <sys/time.h>
+RCSID("$Id: stime.c,v 1.3 1996/05/31 21:00:24 assar Exp $");
 
 /*
  * Given a pointer to a long containing the number of seconds
