@@ -26,11 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: tf_util.c,v 1.7 1996/03/25 13:09:58 bg Exp $");
-
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/file.h>
+RCSID("$Id: tf_util.c,v 1.10 1996/06/01 00:05:10 assar Exp $");
 
 #ifdef TKT_SHMEM
 #include <sys/param.h>
@@ -101,8 +97,12 @@ static tf_gets(register char *s, int n), tf_read(register char *s, register int
  *
  * tf_get_pname() returns the principal's name.
  *
+ * tf_put_pname() writes the principal's name to the ticket file.
+ *
  * tf_get_pinst() returns the principal's instance (may be null).
  *
+ * tf_put_pinst() writes the instance.
+ *
  * tf_get_cred() returns the next CREDENTIALS record.
  *
  * tf_save_cred() appends a new CREDENTIAL record to the ticket file.
@@ -177,12 +177,6 @@ tf_init(char *tf_name, int rw)
     if(!S_ISREG(stat_buf.st_mode))
       return TKT_FIL_ACC;
 
-#if 0
-    me = getuid();
-    if ((stat_buf.st_uid != me && me != 0) ||
-	((stat_buf.st_mode & S_IFMT) != S_IFREG))
-	return TKT_FIL_ACC;
-#endif
 #ifdef TKT_SHMEM
     (void) strcpy(shmidname, tf_name);
     (void) strcat(shmidname, ".shm");
@@ -525,7 +519,7 @@ tf_get_cred(CREDENTIALS *c)
 	return TKT_FIL_FMT;
     }
 #ifdef TKT_SHMEM
-    bcopy(tmp_shm_addr,c->session,KEY_SZ);
+    memcpy(c->session, tmp_shm_addr, KEY_SZ);
     tmp_shm_addr += KEY_SZ;
 #endif /* TKT_SHMEM */
     return KSUCCESS;
@@ -556,7 +550,7 @@ tf_close(void)
 	(void) close(fd);
 	fd = -1;		/* see declaration of fd above */
     }
-    bzero(tfbfr, sizeof(tfbfr));
+    memset(tfbfr, 0, sizeof(tfbfr));
 }
 
 /*
@@ -708,7 +702,7 @@ tf_save_cred(char *service, char *instance, char *realm, unsigned char *session,
 	goto bad;
     /* Session key */
 #ifdef TKT_SHMEM
-    bcopy(session,tmp_shm_addr,8);
+    memcpy(tmp_shm_addr, session, 8);
     tmp_shm_addr+=8;
     if (write(fd,krb_dummy_skey,8) != 8)
 	goto bad;
