@@ -10,11 +10,7 @@
 
 #include "krb_locl.h"
 
-RCSID("$Id: util.c,v 1.3 1996/03/25 13:09:59 bg Exp $");
-
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
+RCSID("$Id: util.c,v 1.4 1996/05/31 21:00:28 assar Exp $");
 
 /*
  * Print some of the contents of the given authenticator structure
