@@ -1,4 +1,4 @@
-/* $Id: roken.h,v 1.10 1996/06/08 21:53:03 joda Exp $ */
+/* $Id: roken.h,v 1.11 1996/06/27 03:56:13 assar Exp $ */
 
 #ifndef __ROKEN_H__
 #define __ROKEN_H__
@@ -71,4 +71,8 @@ char *getstr(char *id, char **cpp);
 #include <pwd.h>
 struct passwd *k_getpwnam (char *user);
 
+#include <time.h>
+#include <sys/time.h>
+time_t tm2time (struct tm tm, int local);
+
 #endif /*  __ROKEN_H__ */
