@@ -9,7 +9,7 @@
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Id: kerberos.c,v 1.26 1996/05/04 02:04:25 d91-jda Exp $");
+RCSID("$Id: kerberos.c,v 1.28 1996/05/29 23:24:53 assar Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -297,7 +297,12 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
     req_version = pkt_version(pkt);	/* 1 byte, version */
     req_msg_type = pkt_msg_type(pkt);	/* 1 byte, Kerberos msg type */
 
+    /* Is there any point in sending back the error reply with the
+       protocol version that we got from the client? */
+
+#if 0
     req_act_vno = req_version;
+#endif
 
     /* check packet version */
     if (req_version != KRB_PROT_VERSION) {
@@ -335,7 +340,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    req_name_ptr = (char *) pkt_a_name(pkt);
 	    req_inst_ptr = (char *) pkt_a_inst(pkt);
 	    req_realm_ptr = (char *) pkt_a_realm(pkt);
-	    bcopy(pkt_time_ws(pkt), &req_time_ws, sizeof(req_time_ws));
+	    memcpy(&req_time_ws, pkt_time_ws(pkt), sizeof(req_time_ws));
 	    /* time has to be diddled */
 	    if (swap_bytes) {
 		swap_u_long(req_time_ws);
@@ -373,7 +378,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    lifetime = min(lifetime, ((u_int32_t) a_name_data.max_life));
 
 #ifdef NOENCRYPTION
-	    bzero(session_key, sizeof(des_cblock));
+	    memset(session_key, 0, sizeof(des_cblock));
 #else /* !NOENCRYPTION */
 	    des_new_random_key(&session_key);
 #endif /* !NOENCRYPTION */
@@ -386,8 +391,8 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 		a_name_data.instance, local_realm,
 		 client_host.s_addr, session_key, lifetime, kerb_time.tv_sec,
 			 s_name_data.name, s_name_data.instance, &key);
-	    bzero(key, sizeof(key));
-	    bzero(key_s, sizeof(key_s));
+	    memset(key, 0, sizeof(key));
+	    memset(key_s, 0, sizeof(key_s));
 
 	    /*
 	     * get the user's key, unseal it from the server's key, and
@@ -406,11 +411,8 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 		  s_name_data.key_version, tk, kerb_time.tv_sec, &key);
 
 	    /* clear session key */
-	    bzero(session_key, sizeof(session_key));
-
-	    bzero(key, sizeof(key));
-
-
+	    memset(session_key, 0, sizeof(session_key));
+	    memset(key, 0, sizeof(key));
 
 	    /* always send a reply packet */
 	    rpkt = create_auth_reply(req_name_ptr, req_inst_ptr,
@@ -418,8 +420,8 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 		a_name_data.key_version, ciph);
 	    sendto(f, (char*)rpkt->dat, rpkt->length, 0, (struct sockaddr *)client,
 		   S_AD_SZ);
-	    bzero(&a_name_data, sizeof(a_name_data));
-	    bzero(&s_name_data, sizeof(s_name_data));
+	    memset(&a_name_data, 0, sizeof(a_name_data));
+	    memset(&s_name_data, 0, sizeof(s_name_data));
 	    break;
 	}
     case AUTH_MSG_APPL_REQUEST:
@@ -443,7 +445,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    auth->length += (int) *(pkt->dat + auth->length) +
 		(int) *(pkt->dat + auth->length + 1) + 2;
 
-	    bcopy(pkt->dat, auth->dat, auth->length);
+	    memcpy(auth->dat, pkt->dat, auth->length);
 
 	    strncpy(tktrlm, (char *)auth->dat + 3, REALM_SZ);
 	    if ((kerno = set_tgtkey(tktrlm))) {
@@ -464,7 +466,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    }
 	    ptr = (char *) pkt->dat + auth->length;
 
-	    bcopy(ptr, &time_ws, 4);
+	    memcpy(&time_ws, ptr, 4);
 	    ptr += 4;
 
 	    req_life = (unsigned char) (*ptr++);
@@ -504,7 +506,7 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 	    /* construct and seal the ticket */
 
 #ifdef NOENCRYPTION
-	    bzero(session_key, sizeof(des_cblock));
+	    memset(session_key, 0, sizeof(des_cblock));
 #else /* !NOENCRYPTION */
 	    des_new_random_key(&session_key);
 #endif /* !NOENCRYPTION */
@@ -514,8 +516,8 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 			      session_key, lifetime, kerb_time.tv_sec,
 			      s_name_data.name, s_name_data.instance,
 			      &key);
-	    bzero(key, sizeof(key));
-	    bzero(key_s, sizeof(key_s));
+	    memset(key, 0, sizeof(key));
+	    memset(key_s, 0, sizeof(key_s));
 
 	    create_ciph(ciph, session_key, service, instance,
 			local_realm,
@@ -523,16 +525,16 @@ kerberos(int f, struct sockaddr_in *client, KTEXT pkt)
 			kerb_time.tv_sec, &ad->session);
 
 	    /* clear session key */
-	    bzero(session_key, sizeof(session_key));
+	    memset(session_key, 0, sizeof(session_key));
 
-	    bzero(ad->session, sizeof(ad->session));
+	    memset(ad->session, 0, sizeof(ad->session));
 
 	    rpkt = create_auth_reply(ad->pname, ad->pinst,
 				     ad->prealm, time_ws,
 				     0, 0, 0, ciph);
 	    sendto(f, (char*)rpkt->dat, rpkt->length, 0, 
 		   (struct sockaddr *)client, S_AD_SZ);
-	    bzero(&s_name_data, sizeof(s_name_data));
+	    memset(&s_name_data, 0, sizeof(s_name_data));
 	    break;
 	}
 
@@ -625,7 +627,7 @@ mksocket(struct in_addr addr, const char *service, int port)
     if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (void *)&on,
 		   sizeof(on)) < 0)
 	fprintf(stderr, "%s: setsockopt (SO_REUSEADDR)\n", progname);
-    bzero(&sina, sizeof(sina));
+    memset(&sina, 0, sizeof(sina));
     sina.sin_family = AF_INET;
     sina.sin_port   = port;
     sina.sin_addr   = addr;
@@ -845,8 +847,8 @@ main(int argc, char **argv)
     kerror = kdb_verify_master_key (&master_key, master_key_schedule, stdout);
     if (kerror < 0) {
       klog (L_KRB_PERR, "Can't verify master key.");
-      bzero (master_key, sizeof (master_key));
-      bzero (master_key_schedule, sizeof (master_key_schedule));
+      memset(master_key, 0, sizeof (master_key));
+      memset (master_key_schedule, 0, sizeof (master_key_schedule));
       exit (-1);
     }
 
