@@ -4,15 +4,18 @@
  * For copyright info, see mit-sipb-copyright.h.
  */
 
+#if 0
+static const char copyright[] =
+    "Copyright 1987,1988 by Student Information Processing Board, Massachusetts Institute of Technology";
+#endif
+
 #include "error_table.h"
 #include "mit-sipb-copyright.h"
 #include "internal.h"
 
 #ifndef	lint
-static const char copyright[] =
-    "Copyright 1987,1988 by Student Information Processing Board, Massachusetts Institute of Technology";
-static const char rcsid_et_name_c[] =
-    "$Header: /src/packages/kth-krb/SourceRepository/krb4/util/et/et_name.c,v 1.2 1996/02/07 10:48:49 d91-jda Exp $";
+static const char
+rcsid_et_name_c[] = "$Id: et_name.c,v 1.4 1996/06/12 08:03:49 bg Exp $";
 #endif
 
 static const char char_set[] =
