@@ -9,22 +9,20 @@
 #include "copyright.h"
 #include "ss_internal.h"
 
-#define ssrt ss_request_table	/* for some readable code... */
-
-void ss_add_request_table(int sci_idx, ssrt *rqtbl_ptr, 
+void ss_add_request_table(int sci_idx, ss_request_table *rqtbl_ptr, 
 			  int position, int *code_ptr)
 {
 	register ss_data *info;
 	register int i, size;
 
 	info = ss_info(sci_idx);
-	for (size=0; info->rqt_tables[size] != (ssrt *)NULL; size++)
+	for (size=0; info->rqt_tables[size] != (ss_request_table *)NULL; size++)
 		;
 	/* size == C subscript of NULL == #elements */
 	size += 2;		/* new element, and NULL */
-	info->rqt_tables = (ssrt **)realloc((char *)info->rqt_tables,
-					    (unsigned)size*sizeof(ssrt));
-	if (info->rqt_tables == (ssrt **)NULL) {
+	info->rqt_tables = (ss_request_table **)realloc((char *)info->rqt_tables,
+					    (unsigned)size*sizeof(ss_request_table));
+	if (info->rqt_tables == (ss_request_table **)NULL) {
 		*code_ptr = errno;
 		return;
 	}
@@ -36,14 +34,14 @@ void ss_add_request_table(int sci_idx, ssrt *rqtbl_ptr,
 			info->rqt_tables[i+1] = info->rqt_tables[i];
 
 	info->rqt_tables[position] = rqtbl_ptr;
-	info->rqt_tables[size-1] = (ssrt *)NULL;
+	info->rqt_tables[size-1] = (ss_request_table *)NULL;
 	*code_ptr = 0;
 }
 
-void ss_delete_request_table(int sci_idx, ssrt *rqtbl_ptr, int *code_ptr)
+void ss_delete_request_table(int sci_idx, ss_request_table *rqtbl_ptr, int *code_ptr)
 {
      register ss_data *info;
-     register ssrt **rt1, **rt2;
+     register ss_request_table **rt1, **rt2;
 
      *code_ptr = SS_ET_TABLE_NOT_FOUND;
      info = ss_info(sci_idx);
@@ -54,6 +52,6 @@ void ss_delete_request_table(int sci_idx, ssrt *rqtbl_ptr, int *code_ptr)
 	       *code_ptr = 0;
 	  }
      }
-     *rt2 = (ssrt *)NULL;
+     *rt2 = (ss_request_table *)NULL;
      return;
 }
